@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include <mitkBaseApplication.h>
 
@@ -21,7 +17,7 @@ See LICENSE.txt or http://www.mitk.org for details.
 #include <QFileInfo>
 #include <QVariant>
 
-int main(int argc, char** argv)
+int main(int argc, char **argv)
 {
   mitk::BaseApplication app(argc, argv);
   app.setApplicationName("BlueBerryExampleLauncher");
@@ -31,7 +27,8 @@ int main(int argc, char** argv)
   BlueBerryExampleLauncherDialog demoDialog;
   QString selectedConfiguration = demoDialog.getDemoConfiguration();
 
-  if (selectedConfiguration.isEmpty()) return EXIT_SUCCESS;
+  if (selectedConfiguration.isEmpty())
+    return EXIT_SUCCESS;
 
   app.setProvisioningFilePath(selectedConfiguration);
 
