@@ -1,19 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
-
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
+============================================================================*/
 
 #ifndef BLUEBERRYEXAMPLELAUNCHERDIALOG_H
 #define BLUEBERRYEXAMPLELAUNCHERDIALOG_H
@@ -23,8 +18,9 @@ See LICENSE.txt or http://www.mitk.org for details.
 #include <QEventLoop>
 #include <QStringList>
 
-namespace Ui {
-class BlueBerryExampleLauncherDialog;
+namespace Ui
+{
+  class BlueBerryExampleLauncherDialog;
 }
 
 class BlueBerryExampleLauncherDialog : public QDialog
@@ -33,19 +29,17 @@ class BlueBerryExampleLauncherDialog : public QDialog
 
 public:
   explicit BlueBerryExampleLauncherDialog(QWidget *parent = nullptr);
-  ~BlueBerryExampleLauncherDialog();
+  ~BlueBerryExampleLauncherDialog() override;
 
   QString getDemoConfiguration();
 
 private:
-
   Q_SLOT void configurationSelected();
   Q_SLOT void dialogCanceled();
 
   Q_SLOT void selectionChanged(int row);
 
 private:
-
   Ui::BlueBerryExampleLauncherDialog *ui;
   QStringList provisioningFiles;
   QList<QString> descriptions;
