@@ -1,3 +1,15 @@
+/*============================================================================
+
+The Medical Imaging Interaction Toolkit (MITK)
+
+Copyright (c) German Cancer Research Center (DKFZ)
+All rights reserved.
+
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
+
+============================================================================*/
+
 #ifndef mitkEndoDebugFromXmlFile_h
 #define mitkEndoDebugFromXmlFile_h
 
@@ -46,4 +58,4 @@ namespace mitk
 
 } // namespace mitk
 
-#endif // mitkEndoDebugFromXmlFile_h
+#endif
