@@ -1,44 +1,38 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
-#ifndef _MITK_CONTOURMODEL_H_
-#define _MITK_CONTOURMODEL_H_
+============================================================================*/
+#ifndef mitkContourModel_h
+#define mitkContourModel_h
 
+#include "mitkBaseData.h"
 #include "mitkCommon.h"
 #include <MitkContourModelExports.h>
-#include "mitkBaseData.h"
 
 #include <mitkContourElement.h>
 
-
 namespace mitk
 {
-
   /**
   \brief ContourModel is a structure of linked vertices defining a contour in 3D space.
-  The vertices are stored in a mitk::ContourElement is stored for each timestep.
+  The vertices are stored in a mitk::ContourElement for each timestep.
   The contour line segments are implicitly defined by the given linked vertices.
-  By default two control points are are linked by a straight line.It is possible to add
-  vertices at front and end of the contour and to iterate in both directions.
+  By default two control points are linked by a straight line. It is possible to add
+  vertices at the front and end of the contour and to iterate in both directions.
 
   Points are specified containing coordinates and additional (data) information,
   see mitk::ContourElement.
-  For accessing a specific vertex either an index or a position in 3D Space can be used.
+  For accessing a specific vertex either an index or a position in 3D space can be used.
   The vertices are best accessed by using a VertexIterator.
   Interaction with the contour is thus available without any mitk interactor class using the
-  api of ContourModel. It is possible to shift single vertices also as shifting the whole
+  api of ContourModel. It is possible to shift single vertices as well as shifting the whole
   contour.
 
   A contour can be either open like a single curved line segment or
@@ -52,49 +46,39 @@ namespace mitk
   */
   class MITKCONTOURMODEL_EXPORT ContourModel : public BaseData
   {
-
   public:
-
     mitkClassMacro(ContourModel, BaseData);
 
-    itkFactorylessNewMacro(Self)
-    itkCloneMacro(Self)
+    itkFactorylessNewMacro(Self);
+
+    itkCloneMacro(Self);
 
     /*+++++++++++++++ typedefs +++++++++++++++++++++++++++++++*/
-    typedef mitk::ContourElement::VertexType VertexType;
-    typedef mitk::ContourElement::VertexListType VertexListType;
-    typedef mitk::ContourElement::VertexIterator VertexIterator;
-    typedef mitk::ContourElement::ConstVertexIterator ConstVertexIterator;
-    typedef std::vector< mitk::ContourElement::Pointer > ContourModelSeries;
+    typedef ContourElement::VertexType VertexType;
+    typedef ContourElement::VertexListType VertexListType;
+    typedef ContourElement::VertexIterator VertexIterator;
+    typedef ContourElement::ConstVertexIterator ConstVertexIterator;
+    typedef std::vector<ContourElement::Pointer> ContourModelSeries;
     /*+++++++++++++++ END typedefs ++++++++++++++++++++++++++++*/
 
-
     /** \brief Possible interpolation of the line segments between control points */
-    enum LineSegmentInterpolation{
-      LINEAR, B_SPLINE
+    enum LineSegmentInterpolation
+    {
+      LINEAR,
+      B_SPLINE
     };
 
-
-
     /*++++++++++++++++  inline methods  +++++++++++++++++++++++*/
 
     /** \brief Get the current selected vertex.
     */
-    VertexType* GetSelectedVertex()
-    {
-      return this->m_SelectedVertex;
-    }
-
+    VertexType *GetSelectedVertex() { return this->m_SelectedVertex; }
     /** \brief Deselect vertex.
     */
-    void Deselect()
-    {
-      this->m_SelectedVertex = nullptr;
-    }
-
+    void Deselect() { this->m_SelectedVertex = nullptr; }
     /** \brief Set selected vertex as control point
     */
-    void SetSelectedVertexAsControlPoint(bool isControlPoint=true)
+    void SetSelectedVertexAsControlPoint(bool isControlPoint = true)
     {
       if (this->m_SelectedVertex)
       {
@@ -113,58 +97,47 @@ namespace mitk
 
     /** \brief Get the interpolation of the line segments between control points.
     */
-    LineSegmentInterpolation GetLineSegmentInterpolation()
-    {
-      return this->m_lineInterpolation;
-    }
+    LineSegmentInterpolation GetLineSegmentInterpolation() { return this->m_lineInterpolation; }
     /*++++++++++++++++  END inline methods  +++++++++++++++++++++++*/
 
-
     /** \brief Add a vertex to the contour at given timestep.
     The vertex is added at the end of contour.
 
     \param vertex - coordinate representation of a control point
     \param timestep - the timestep at which the vertex will be add ( default 0)
 
-    @Note Adding a vertex to a timestep which exceeds the timebounds of the contour
+    @note Adding a vertex to a timestep which exceeds the timebounds of the contour
     will not be added, the TimeGeometry will not be expanded.
     */
-    void AddVertex(mitk::Point3D &vertex, int timestep=0);
+    void AddVertex(const Point3D &vertex, TimeStepType timestep = 0);
 
     /** \brief Add a vertex to the contour at given timestep.
-    The vertex is added at the end of contour.
-
+    A copy of the passed vertex is added at the end of contour.
     \param vertex - coordinate representation of a control point
     \param timestep - the timestep at which the vertex will be add ( default 0)
-
-    @Note Adding a vertex to a timestep which exceeds the timebounds of the contour
+    @note Adding a vertex to a timestep which exceeds the timebounds of the contour
     will not be added, the TimeGeometry will not be expanded.
     */
-    void AddVertex(VertexType &vertex, int timestep=0);
-
-    /** \brief Add a vertex to the contour at given timestep.
-    The vertex is added at the end of contour.
-
-    \param vertex - coordinate representation of a control point
-    \param timestep - the timestep at which the vertex will be add ( default 0)
-
-    @Note Adding a vertex to a timestep which exceeds the timebounds of the contour
-    will not be added, the TimeSlicedGeometry will not be expanded.
-    */
-    void AddVertex(const VertexType* vertex, int timestep=0);
+    void AddVertex(const VertexType &vertex, TimeStepType timestep = 0);
 
     /** \brief Add a vertex to the contour.
-
     \param vertex - coordinate representation of a control point
     \param timestep - the timestep at which the vertex will be add ( default 0)
     \param isControlPoint - specifies the vertex to be handled in a special way (e.g. control points
     will be rendered).
-
-
-    @Note Adding a vertex to a timestep which exceeds the timebounds of the contour
+    @note Adding a vertex to a timestep which exceeds the timebounds of the contour
     will not be added, the TimeGeometry will not be expanded.
     */
-    void AddVertex(mitk::Point3D &vertex, bool isControlPoint, int timestep=0);
+    void AddVertex(const Point3D& vertex, bool isControlPoint, TimeStepType timestep = 0);
+
+    /** Clears the contour of destinationTimeStep and copies
+        the contour of the passed source model at the sourceTimeStep.
+     @pre soureModel must point to a valid instance
+     @pre sourceTimePoint must be valid
+     @note Updating a vertex to a timestep which exceeds the timebounds of the contour
+      will not be added, the TimeGeometry will not be expanded.
+    */
+    void UpdateContour(const ContourModel* sourceModel, TimeStepType destinationTimeStep, TimeStepType sourceTimeStep);
 
     /** \brief Add a vertex to the contour at given timestep AT THE FRONT of the contour.
     The vertex is added at the FRONT of contour.
@@ -172,10 +145,10 @@ namespace mitk
     \param vertex - coordinate representation of a control point
     \param timestep - the timestep at which the vertex will be add ( default 0)
 
-    @Note Adding a vertex to a timestep which exceeds the timebounds of the contour
+    @note Adding a vertex to a timestep which exceeds the timebounds of the contour
     will not be added, the TimeGeometry will not be expanded.
     */
-    void AddVertexAtFront(mitk::Point3D &vertex, int timestep=0);
+    void AddVertexAtFront(const Point3D &vertex, TimeStepType timestep = 0);
 
     /** \brief Add a vertex to the contour at given timestep AT THE FRONT of the contour.
     The vertex is added at the FRONT of contour.
@@ -183,10 +156,10 @@ namespace mitk
     \param vertex - coordinate representation of a control point
     \param timestep - the timestep at which the vertex will be add ( default 0)
 
-    @Note Adding a vertex to a timestep which exceeds the timebounds of the contour
+    @note Adding a vertex to a timestep which exceeds the timebounds of the contour
     will not be added, the TimeGeometry will not be expanded.
     */
-    void AddVertexAtFront(VertexType &vertex, int timestep=0);
+    void AddVertexAtFront(const VertexType &vertex, TimeStepType timestep = 0);
 
     /** \brief Add a vertex to the contour at given timestep AT THE FRONT of the contour.
 
@@ -196,110 +169,155 @@ namespace mitk
     will be rendered).
 
 
-    @Note Adding a vertex to a timestep which exceeds the timebounds of the contour
+    @note Adding a vertex to a timestep which exceeds the timebounds of the contour
     will not be added, the TimeGeometry will not be expanded.
     */
-    void AddVertexAtFront(mitk::Point3D &vertex, bool isControlPoint, int timestep=0);
+    void AddVertexAtFront(const Point3D &vertex, bool isControlPoint, TimeStepType timestep = 0);
 
     /** \brief Insert a vertex at given index.
     */
-    void InsertVertexAtIndex(mitk::Point3D &vertex, int index, bool isControlPoint=false, int timestep=0);
+    void InsertVertexAtIndex(const Point3D &vertex, int index, bool isControlPoint = false, TimeStepType timestep = 0);
 
     /** \brief Set a coordinates for point at given index.
     */
-    bool SetVertexAt(int pointId, const mitk::Point3D &point, unsigned int timestep=0);
+    bool SetVertexAt(int pointId, const Point3D &point, TimeStepType timestep = 0);
 
-    /** \brief Set a coordinates for point at given index.
+    /** \brief Set a coordinates and control state for point at given index.
     */
-    bool SetVertexAt(int pointId, const VertexType* vertex, unsigned int timestep=0);
+    bool SetVertexAt(int pointId, const VertexType *vertex, TimeStepType timestep = 0);
 
     /** \brief Return if the contour is closed or not.
     */
-    bool IsClosed( int timestep=0) const;
+    bool IsClosed(int timestep = 0) const;
 
     /** \brief Concatenate two contours.
     The starting control point of the other will be added at the end of the contour.
-    \pararm timestep - the timestep at which the vertex will be add ( default 0)
-    \pararm check - check for intersections ( default false)
+    \param other
+    \param timestep - the timestep at which the vertex will be add ( default 0)
+    \param check - check for intersections ( default false)
     */
-    void Concatenate(mitk::ContourModel* other, int timestep=0, bool check=false);
+    void Concatenate(ContourModel *other, TimeStepType timestep = 0, bool check = false);
 
     /** \brief Returns a const VertexIterator at the start element of the contour.
     @throw mitk::Exception if the timestep is invalid.
     */
-    VertexIterator Begin( int timestep=0) const;
+    VertexIterator Begin(TimeStepType timestep = 0) const;
 
     /** \brief Returns a const VertexIterator at the start element of the contour.
     @throw mitk::Exception if the timestep is invalid.
     */
-    VertexIterator IteratorBegin( int timestep=0) const;
+    VertexIterator IteratorBegin(TimeStepType timestep = 0) const;
 
     /** \brief Returns a const VertexIterator at the end element of the contour.
     @throw mitk::Exception if the timestep is invalid.
     */
-    VertexIterator End( int timestep=0) const;
+    VertexIterator End(TimeStepType timestep = 0) const;
 
     /** \brief Returns a const VertexIterator at the end element of the contour.
     @throw mitk::Exception if the timestep is invalid.
     */
-    VertexIterator IteratorEnd( int timestep=0) const;
+    VertexIterator IteratorEnd(TimeStepType timestep = 0) const;
 
     /** \brief Close the contour.
     The last control point will be linked with the first point.
     */
-    virtual void Close( int timestep=0);
+    virtual void Close(TimeStepType timestep = 0);
 
     /** \brief Set isClosed to false contour.
     The link between the last control point the first point will be removed.
     */
-    virtual void Open( int timestep=0);
+    virtual void Open(TimeStepType timestep = 0);
 
     /** \brief Set closed property to given boolean.
 
     false - The link between the last control point the first point will be removed.
     true - The last control point will be linked with the first point.
     */
-    virtual void SetClosed(bool isClosed, int timestep=0);
+    virtual void SetClosed(bool isClosed, TimeStepType timestep = 0);
 
     /** \brief Returns the number of vertices at a given timestep.
     \param timestep - default = 0
     */
-    int GetNumberOfVertices( int timestep=0) const;
+    int GetNumberOfVertices(TimeStepType timestep = 0) const;
 
     /** \brief Returns whether the contour model is empty at a given timestep.
-    \pararm timestep - default = 0
+    \param timestep - default = 0
     */
-    virtual bool IsEmpty( int timestep) const;
+    virtual bool IsEmpty(TimeStepType timestep) const;
 
     /** \brief Returns whether the contour model is empty.
     */
-    virtual bool IsEmpty() const override;
+    bool IsEmpty() const override;
 
     /** \brief Returns the vertex at the index position within the container.
+    * If the index or timestep is invalid a nullptr will be returned.
     */
-    virtual const VertexType* GetVertexAt(int index, int timestep=0) const;
+    virtual const VertexType *GetVertexAt(int index, TimeStepType timestep = 0) const;
+
+    const VertexType *GetVertexAt(mitk::Point3D &point, float eps, TimeStepType timestep) const;
+
+    /** Returns the next control vertex to the approximate nearest vertex of a given position in 3D space
+     * If the timestep is invalid a nullptr will be returned.
+     */
+    virtual const VertexType *GetNextControlVertexAt(mitk::Point3D &point, float eps, TimeStepType timestep) const;
+
+    /** Returns the previous control vertex to the approximate nearest vertex of a given position in 3D space
+     * If the timestep is invalid a nullptr will be returned.
+     */
+    virtual const VertexType *GetPreviousControlVertexAt(mitk::Point3D &point, float eps, TimeStepType timestep) const;
 
     /** \brief Remove a vertex at given timestep within the container.
 
     \return index of vertex. -1 if not found.
     */
-    int GetIndex(const VertexType* vertex, int timestep=0);
+    int GetIndex(const VertexType *vertex, TimeStepType timestep = 0);
 
     /** \brief Check if there isn't something at this timestep.
     */
-    virtual bool IsEmptyTimeStep(unsigned int t) const override;
+    bool IsEmptyTimeStep(unsigned int t) const override;
 
     /** \brief Check if mouse cursor is near the contour.
     */
-    virtual bool IsNearContour(mitk::Point3D &point, float eps, int timestep);
+    bool IsNearContour(Point3D &point, float eps, TimeStepType timestep) const;
+
+    /** Function that searches for the line segment of the contour that is closest to the passed point
+    and close enough (distance between point and line segment <= eps). If such an line segment exist,
+    the starting vertex and closing vertex of the found segment are passed back.
+    @return True indicates that a line segment was found. False indicates that no segment of the contour
+    is close enough to the passed point.
+    @remark previousVertex and nextVertex are only valid if return is true.*/
+    bool GetLineSegmentForPoint(Point3D &point,
+                            float eps,
+                            TimeStepType timestep,
+                            mitk::ContourElement::VertexType *previousVertex = nullptr,
+                            mitk::ContourElement::VertexType *nextVertex = nullptr);
+
+    /**Overloaded version that returns additional information (start and end vertix of the line
+    closest to the passed point and the closest point on the contour).
+    @remark segmentStart, segmentStop and closestContourPoint are only valid if the function returns true.
+    */
+    bool GetLineSegmentForPoint(const mitk::Point3D& point,
+      float eps, TimeStepType timestep, ContourElement::VertexSizeType& segmentStartIndex,
+      ContourElement::VertexSizeType& segmentEndIndex, mitk::Point3D& closestContourPoint,
+      bool findClosest = true) const;
 
     /** \brief Mark a vertex at an index in the container as selected.
-    */
-    bool SelectVertexAt(int index, int timestep=0);
+     */
+    bool SelectVertexAt(int index, TimeStepType timestep = 0);
 
     /** \brief Mark a vertex at an index in the container as control point.
     */
-    bool SetControlVertexAt(int index, int timestep=0);
+    bool SetControlVertexAt(int index, TimeStepType timestep = 0);
+
+    /** \brief Mark a control vertex at a given position in 3D space.
+
+    \param point - query point in 3D space
+    \param eps - radius for nearest neighbour search (error bound).
+    \param timestep - search at this timestep
+
+    @return true = vertex found;  false = no vertex found
+    */
+    bool SelectControlVertexAt(Point3D &point, float eps, TimeStepType timestep = 0);
 
     /** \brief Mark a vertex at a given position in 3D space.
 
@@ -309,27 +327,28 @@ namespace mitk
 
     @return true = vertex found;  false = no vertex found
     */
-    bool SelectVertexAt(mitk::Point3D &point, float eps, int timestep=0);
-/*
-    \pararm point - query point in 3D space
-    \pararm eps - radius for nearest neighbour search (error bound).
-    \pararm timestep - search at this timestep
+    bool SelectVertexAt(Point3D &point, float eps, TimeStepType timestep = 0);
 
-    @return true = vertex found;  false = no vertex found
-    */
-    bool SetControlVertexAt(mitk::Point3D &point, float eps, int timestep=0);
+    /*
+        \pararm point - query point in 3D space
+        \pararm eps - radius for nearest neighbour search (error bound).
+        \pararm timestep - search at this timestep
+
+        @return true = vertex found;  false = no vertex found
+        */
+    bool SetControlVertexAt(Point3D &point, float eps, TimeStepType timestep = 0);
 
     /** \brief Remove a vertex at given index within the container.
 
     @return true = the vertex was successfuly removed;  false = wrong index.
     */
-    bool RemoveVertexAt(int index, int timestep=0);
+    bool RemoveVertexAt(int index, TimeStepType timestep = 0);
 
     /** \brief Remove a vertex at given timestep within the container.
 
     @return true = the vertex was successfuly removed.
     */
-    bool RemoveVertex(const VertexType* vertex, int timestep=0);
+    bool RemoveVertex(const VertexType *vertex, TimeStepType timestep = 0);
 
     /** \brief Remove a vertex at a query position in 3D space.
 
@@ -339,80 +358,77 @@ namespace mitk
 
     @return true = the vertex was successfuly removed;  false = no vertex found.
     */
-    bool RemoveVertexAt(mitk::Point3D &point, float eps, int timestep=0);
+    bool RemoveVertexAt(Point3D &point, float eps, TimeStepType timestep = 0);
 
     /** \brief Shift the currently selected vertex by a translation vector.
 
     \param translate - the translation vector.
     */
-    void ShiftSelectedVertex(mitk::Vector3D &translate);
+    void ShiftSelectedVertex(Vector3D &translate);
 
     /** \brief Shift the whole contour by a translation vector at given timestep.
 
     \param translate - the translation vector.
     \param timestep - at this timestep the contour will be shifted.
     */
-    void ShiftContour(mitk::Vector3D &translate, int timestep=0);
+    void ShiftContour(Vector3D &translate, TimeStepType timestep = 0);
 
     /** \brief Clear the storage container at given timestep.
 
     All control points are removed at
     timestep.
     */
-    virtual void Clear(int timestep);
+    virtual void Clear(TimeStepType timestep);
 
     /** \brief Initialize all data objects
     */
-    virtual void Initialize() override;
+    void Initialize() override;
 
     /** \brief Initialize object with specs of other contour.
     Note: No data will be copied.
     */
-    void Initialize(mitk::ContourModel &other);
+    void Initialize(const ContourModel &other);
 
+    /** \brief Returns a list pointing to all vertices that are indicated to be control points.
+    */
+    VertexListType GetControlVertices(TimeStepType timestep);
+
+    /** \brief Returns the container of the vertices.
+     */
+    VertexListType GetVertexList(TimeStepType timestep);
 
     /*++++++++++++++++++ method inherit from base data +++++++++++++++++++++++++++*/
     /**
     \brief Inherit from base data - no region support available for contourModel objects.
     */
-    virtual void SetRequestedRegionToLargestPossibleRegion () override;
+    void SetRequestedRegionToLargestPossibleRegion() override;
 
     /**
     \brief Inherit from base data - no region support available for contourModel objects.
     */
-    virtual bool RequestedRegionIsOutsideOfTheBufferedRegion () override;
+    bool RequestedRegionIsOutsideOfTheBufferedRegion() override;
 
     /**
     \brief Inherit from base data - no region support available for contourModel objects.
     */
-    virtual bool VerifyRequestedRegion () override;
-
-    /**
-    \brief Get the updated geometry with recomputed bounds.
-    */
-    virtual const mitk::BaseGeometry* GetUpdatedGeometry (int t=0);
-
-    /**
-    \brief Get the BaseGeometry for timestep t.
-    */
-    virtual mitk::BaseGeometry* GetGeometry (int t=0) const;
+    bool VerifyRequestedRegion() override;
 
     /**
     \brief Inherit from base data - no region support available for contourModel objects.
     */
-    virtual void SetRequestedRegion( const itk::DataObject *data) override;
+    void SetRequestedRegion(const itk::DataObject *data) override;
 
     /**
-    \brief Expand the timebounds of the TimeGeometry to given number of timesteps.
+    \brief Expand the contour model and its TimeGeometry to given number of timesteps.
     */
-    virtual void Expand( unsigned int timeSteps ) override;
+    void Expand(unsigned int timeSteps) override;
 
     /**
     \brief Update the OutputInformation of a ContourModel object
 
     The BoundingBox of the contour will be updated, if necessary.
     */
-    virtual void UpdateOutputInformation() override;
+    void UpdateOutputInformation() override;
 
     /**
     \brief Clear the storage container.
@@ -420,55 +436,54 @@ namespace mitk
     The object is set to initial state. All control points are removed and the number of
     timesteps are set to 1.
     */
-    virtual void Clear() override;
+    void Clear() override;
 
     /**
     \brief overwrite if the Data can be called by an Interactor (StateMachine).
     */
-    void ExecuteOperation(Operation* operation) override;
+    void ExecuteOperation(Operation *operation) override;
 
     /** \brief Redistributes ontrol vertices with a given period (as number of vertices)
     \param period - the number of vertices between control points.
     \param timestep - at this timestep all lines will be rebuilt.
     */
-    virtual void RedistributeControlVertices(int period, int timestep);
+    virtual void RedistributeControlVertices(int period, TimeStepType timestep);
 
   protected:
     mitkCloneMacro(Self);
 
     ContourModel();
-    ContourModel(const mitk::ContourModel &other);
-    virtual ~ContourModel();
+    ContourModel(const ContourModel &other);
+    ~ContourModel() override;
 
-    //inherit from BaseData. called by Clear()
-    virtual void ClearData() override;
+    // inherit from BaseData. called by Clear()
+    void ClearData() override;
 
-    //inherit from BaseData. Initial state of a contour with no vertices and a single timestep.
-    virtual void InitializeEmpty() override;
+    // inherit from BaseData. Initial state of a contour with no vertices and a single timestep.
+    void InitializeEmpty() override;
 
-    //Shift a vertex
-    void ShiftVertex(VertexType* vertex, mitk::Vector3D &vector);
+    // Shift a vertex
+    static void ShiftVertex(VertexType *vertex, Vector3D &vector);
 
-    //Storage with time resolved support.
+    // Storage with time resolved support.
     ContourModelSeries m_ContourSeries;
 
-    //The currently selected vertex.
-    VertexType* m_SelectedVertex;
+    // The currently selected vertex.
+    VertexType *m_SelectedVertex;
 
-    //The interpolation of the line segment between control points.
+    // The interpolation of the line segment between control points.
     LineSegmentInterpolation m_lineInterpolation;
 
-    //only update the bounding geometry if necessary
+    // only update the bounding geometry if necessary
     bool m_UpdateBoundingBox;
   };
 
-  itkEventMacro( ContourModelEvent, itk::AnyEvent );
-  itkEventMacro( ContourModelShiftEvent, ContourModelEvent );
-  itkEventMacro( ContourModelSizeChangeEvent, ContourModelEvent );
-  itkEventMacro( ContourModelAddEvent, ContourModelSizeChangeEvent );
-  itkEventMacro( ContourModelRemoveEvent, ContourModelSizeChangeEvent );
-  itkEventMacro( ContourModelExpandTimeBoundsEvent, ContourModelEvent );
-  itkEventMacro( ContourModelClosedEvent, ContourModelEvent );
-
+  itkEventMacroDeclaration(ContourModelEvent, itk::AnyEvent);
+  itkEventMacroDeclaration(ContourModelShiftEvent, ContourModelEvent);
+  itkEventMacroDeclaration(ContourModelSizeChangeEvent, ContourModelEvent);
+  itkEventMacroDeclaration(ContourModelAddEvent, ContourModelSizeChangeEvent);
+  itkEventMacroDeclaration(ContourModelRemoveEvent, ContourModelSizeChangeEvent);
+  itkEventMacroDeclaration(ContourModelExpandTimeBoundsEvent, ContourModelEvent);
+  itkEventMacroDeclaration(ContourModelClosedEvent, ContourModelEvent);
 }
 #endif
