@@ -1,27 +1,22 @@
-/*===================================================================
+/*============================================================================
 
- The Medical Imaging Interaction Toolkit (MITK)
+The Medical Imaging Interaction Toolkit (MITK)
 
- Copyright (c) German Cancer Research Center,
- Division of Medical and Biological Informatics.
- All rights reserved.
+Copyright (c) German Cancer Research Center (DKFZ)
+All rights reserved.
 
- This software is distributed WITHOUT ANY WARRANTY; without
- even the implied warranty of MERCHANTABILITY or FITNESS FOR
- A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
- See LICENSE.txt or http://www.mitk.org for details.
-
- ===================================================================*/
+============================================================================*/
 
 #ifndef mitkEventInformer_h
 #define mitkEventInformer_h
 
-#include "mitkInteractionEventObserver.h"
 #include "mitkInteractionEvent.h"
+#include "mitkInteractionEventObserver.h"
 #include <mitkServiceInterface.h>
 
-
 namespace mitk
 {
   /**
@@ -29,10 +24,7 @@ namespace mitk
    */
   struct EventInformerService
   {
-    virtual ~EventInformerService()
-    {
-    }
-
+    virtual ~EventInformerService() {}
     virtual void RegisterObserver(InteractionEventObserver::Pointer InteractionEventObserver) = 0;
     virtual void UnRegisterObserver(InteractionEventObserver::Pointer InteractionEventObserver) = 0;
     virtual void NotifyObservers(InteractionEvent::Pointer interactionEvent) = 0;
