@@ -1,71 +1,71 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-/**
-* \brief Describes the geometry of a plane object
-*
-* Describes a two-dimensional manifold, i.e., to put it simply,
-* an object that can be described using a 2D coordinate-system.
-*
-* PlaneGeometry can map points between 3D world coordinates
-* (in mm) and the described 2D coordinate-system (in mm) by first projecting
-* the 3D point onto the 2D manifold and then calculating the 2D-coordinates
-* (in mm). These 2D-mm-coordinates can be further converted into
-* 2D-unit-coordinates (e.g., pixels), giving a parameter representation of
-* the object with parameter values inside a rectangle
-* (e.g., [0,0]..[width, height]), which is the bounding box (bounding range
-* in z-direction always [0]..[1]).
-*
-* A PlaneGeometry describes the 2D representation within a 3D object (derived from BaseGeometry). For example,
-* a single CT-image (slice) is 2D in the sense that you can access the
-* pixels using 2D-coordinates, but is also 3D, as the pixels are really
-* voxels, thus have an extension (thickness) in the 3rd dimension.
-*
-*
-* Optionally, a reference BaseGeometry can be specified, which usually would
-* be the geometry associated with the underlying dataset. This is currently
-* used for calculating the intersection of inclined / rotated planes
-* (represented as PlaneGeometry) with the bounding box of the associated
-* BaseGeometry.
-*
-* \warning The PlaneGeometry are not necessarily up-to-date and not even
-* initialized. As described in the previous paragraph, one of the
-* Generate-/Copy-/UpdateOutputInformation methods have to initialize it.
-* mitk::BaseData::GetPlaneGeometry() makes sure, that the PlaneGeometry is
-* up-to-date before returning it (by setting the update extent appropriately
-* and calling UpdateOutputInformation).
-*
-* Rule: everything is in mm (or ms for temporal information) if not
-* stated otherwise.
-* \ingroup Geometry
-*/
-
-#ifndef PLANEGEOMETRY_H_HEADER_INCLUDED_C1C68A2C
-#define PLANEGEOMETRY_H_HEADER_INCLUDED_C1C68A2C
+#ifndef mitkPlaneGeometry_h
+#define mitkPlaneGeometry_h
 
 #include <MitkCoreExports.h>
-#include "mitkBaseGeometry.h"
-#include "mitkRestorePlanePositionOperation.h"
+
+#include <mitkAnatomicalPlanes.h>
+#include <mitkBaseGeometry.h>
+#include <mitkRestorePlanePositionOperation.h>
 
 #include <vnl/vnl_cross.h>
 
-namespace mitk {
-  template < class TCoordRep, unsigned int NPointDimension > class Line;
+namespace mitk
+{
+  template <class TCoordRep, unsigned int NPointDimension>
+  class Line;
   typedef Line<ScalarType, 3> Line3D;
 
+  /**
+   * \brief Describes the geometry of a plane object
+   *
+   * Describes a two-dimensional manifold, i.e., to put it simply,
+   * an object that can be described using a 2D coordinate-system.
+   *
+   * PlaneGeometry can map points between 3D world coordinates
+   * (in mm) and the described 2D coordinate-system (in mm) by first projecting
+   * the 3D point onto the 2D manifold and then calculating the 2D-coordinates
+   * (in mm). These 2D-mm-coordinates can be further converted into
+   * 2D-unit-coordinates (e.g., pixels), giving a parameter representation of
+   * the object with parameter values inside a rectangle
+   * (e.g., [0,0]..[width, height]), which is the bounding box (bounding range
+   * in z-direction always [0]..[1]).
+   *
+   * A PlaneGeometry describes the 2D representation within a 3D object (derived from BaseGeometry). For example,
+   * a single CT-image (slice) is 2D in the sense that you can access the
+   * pixels using 2D-coordinates, but is also 3D, as the pixels are really
+   * voxels, thus have an extension (thickness) in the 3rd dimension.
+   *
+   *
+   * Optionally, a reference BaseGeometry can be specified, which usually would
+   * be the geometry associated with the underlying dataset. This is currently
+   * used for calculating the intersection of inclined / rotated planes
+   * (represented as PlaneGeometry) with the bounding box of the associated
+   * BaseGeometry.
+   *
+   * \warning The PlaneGeometry are not necessarily up-to-date and not even
+   * initialized. As described in the previous paragraph, one of the
+   * Generate-/Copy-/UpdateOutputInformation methods have to initialize it.
+   * mitk::BaseData::GetPlaneGeometry() makes sure, that the PlaneGeometry is
+   * up-to-date before returning it (by setting the update extent appropriately
+   * and calling UpdateOutputInformation).
+   *
+   * Rule: everything is in mm (or ms for temporal information) if not
+   * stated otherwise.
+   * \ingroup Geometry
+   */
+
   class PlaneGeometry;
   /** \deprecatedSince{2014_10} This class is deprecated. Please use PlaneGeometry instead. */
   DEPRECATED(typedef PlaneGeometry Geometry2D);
@@ -81,15 +81,8 @@ namespace mitk {
     mitkClassMacro(PlaneGeometry, BaseGeometry);
 
     /** Method for creation through the object factory. */
-    itkFactorylessNewMacro(Self)
-      itkCloneMacro(Self)
-
-    enum PlaneOrientation
-    {
-      Axial,
-      Sagittal,
-      Frontal
-    };
+    itkFactorylessNewMacro(Self);
+    itkCloneMacro(Self);
 
     virtual void IndexToWorld(const Point2D &pt_units, Point2D &pt_mm) const;
 
@@ -98,9 +91,12 @@ namespace mitk {
     //##Documentation
     //## @brief Convert (continuous or discrete) index coordinates of a \em vector
     //## \a vec_units to world coordinates (in mm)
-    //## @deprecated First parameter (Point2D) is not used. If possible, please use void IndexToWorld(const mitk::Vector2D& vec_units, mitk::Vector2D& vec_mm) const.
+    //## @deprecated First parameter (Point2D) is not used. If possible, please use void IndexToWorld(const
+    // mitk::Vector2D& vec_units, mitk::Vector2D& vec_mm) const.
     //## For further information about coordinates types, please see the Geometry documentation
-    virtual void IndexToWorld(const mitk::Point2D &atPt2d_untis, const mitk::Vector2D &vec_units, mitk::Vector2D &vec_mm) const;
+    virtual void IndexToWorld(const mitk::Point2D &atPt2d_untis,
+                              const mitk::Vector2D &vec_units,
+                              mitk::Vector2D &vec_mm) const;
 
     //##Documentation
     //## @brief Convert (continuous or discrete) index coordinates of a \em vector
@@ -111,9 +107,12 @@ namespace mitk {
     //##Documentation
     //## @brief Convert world coordinates (in mm) of a \em vector
     //## \a vec_mm to (continuous!) index coordinates.
-    //## @deprecated First parameter (Point2D) is not used. If possible, please use void WorldToIndex(const mitk::Vector2D& vec_mm, mitk::Vector2D& vec_units) const.
+    //## @deprecated First parameter (Point2D) is not used. If possible, please use void WorldToIndex(const
+    // mitk::Vector2D& vec_mm, mitk::Vector2D& vec_units) const.
     //## For further information about coordinates types, please see the Geometry documentation
-    virtual void WorldToIndex(const mitk::Point2D &atPt2d_mm, const mitk::Vector2D &vec_mm, mitk::Vector2D &vec_units) const;
+    virtual void WorldToIndex(const mitk::Point2D &atPt2d_mm,
+                              const mitk::Vector2D &vec_mm,
+                              mitk::Vector2D &vec_units) const;
 
     //##Documentation
     //## @brief Convert world coordinates (in mm) of a \em vector
@@ -122,7 +121,7 @@ namespace mitk {
     virtual void WorldToIndex(const mitk::Vector2D &vec_mm, mitk::Vector2D &vec_units) const;
 
     /**
-    * \brief Initialize a plane with orientation \a planeorientation
+    * \brief Initialize a plane with orientation \a AnatomicalPlane
     * (default: axial) with respect to \a BaseGeometry (default: identity).
     * Spacing also taken from \a BaseGeometry.
     *
@@ -138,41 +137,71 @@ namespace mitk {
     *   thisgeometry->SetExtentInMM(2, 1.0);
     * \endcode
     */
-    virtual void InitializeStandardPlane(const BaseGeometry* geometry3D,
-      PlaneOrientation planeorientation = Axial, ScalarType zPosition = 0,
-      bool frontside = true, bool rotated = false);
+    virtual void InitializeStandardPlane(const BaseGeometry *geometry3D,
+                                         AnatomicalPlane planeorientation = AnatomicalPlane::Axial,
+                                         ScalarType zPosition = 0,
+                                         bool frontside = true,
+                                         bool rotated = false,
+                                         bool top = true);
 
     /**
-    * \brief Initialize a plane with orientation \a planeorientation
+    * \brief Initialize a plane with orientation \a AnatomicalPlane
     * (default: axial) with respect to \a BaseGeometry (default: identity).
     * Spacing also taken from \a BaseGeometry.
     *
+    * \param geometry3D
     * \param top if \a true, create plane at top, otherwise at bottom
-    * (for PlaneOrientation Axial, for other plane locations respectively)
+    * (for AnatomicalPlane Axial, for other plane locations respectively)
+    * \param planeorientation
+    * \param frontside
+    * \param rotated
     */
-    virtual void InitializeStandardPlane(const BaseGeometry* geometry3D, bool top,
-      PlaneOrientation planeorientation = Axial,
-      bool frontside = true, bool rotated = false);
+    virtual void InitializeStandardPlane(const BaseGeometry *geometry3D,
+                                         bool top,
+                                         AnatomicalPlane planeorientation = AnatomicalPlane::Axial,
+                                         bool frontside = true,
+                                         bool rotated = false);
 
     /**
-    * \brief Initialize a plane with orientation \a planeorientation
+    * \brief Initialize a plane with orientation \a AnatomicalPlane
     * (default: axial) with respect to \a transform (default: identity)
     * given width and height in units.
     *
+    * \a Rotated means rotated by 180 degrees (1/2 rotation) within the plane.
+    * Rotation by 90 degrees (1/4 rotation) is not implemented as of now.
+    *
+    * \a Frontside/Backside:
+    * Viewed from below = frontside in the axial case;
+    * (radiologist's view versus neuro-surgeon's view, see:
+    * http://www.itk.org/Wiki/images/e/ed/DICOM-OrientationDiagram-Radiologist-vs-NeuroSurgeon.png )
+    * Viewed from front = frontside in the coronal case;
+    * Viewed from left = frontside in the sagittal case.
+    *
+    * \a Cave/Caution: Currently only RPI, LAI, LPS and RAS in the three standard planes are covered,
+    * i.e. 12 cases of 144:  3 standard planes * 48 coordinate orientations = 144 cases.
     */
-    virtual void InitializeStandardPlane(ScalarType width, ScalarType height,
-      const AffineTransform3D* transform = nullptr,
-      PlaneOrientation planeorientation = Axial,
-      ScalarType zPosition = 0, bool frontside = true, bool rotated = false);
+    virtual void InitializeStandardPlane(ScalarType width,
+                                         ScalarType height,
+                                         const AffineTransform3D *transform = nullptr,
+                                         AnatomicalPlane planeorientation = AnatomicalPlane::Axial,
+                                         ScalarType zPosition = 0,
+                                         bool frontside = true,
+                                         bool rotated = false,
+                                         bool top = true);
 
     /**
-    * \brief Initialize plane with orientation \a planeorientation
+    * \brief Initialize plane with orientation \a AnatomicalPlane
     * (default: axial) given width, height and spacing.
     *
     */
-    virtual void InitializeStandardPlane(ScalarType width, ScalarType height,
-      const Vector3D & spacing, PlaneOrientation planeorientation = Axial,
-      ScalarType zPosition = 0, bool frontside = true, bool rotated = false);
+    virtual void InitializeStandardPlane(ScalarType width,
+                                         ScalarType height,
+                                         const Vector3D &spacing,
+                                         AnatomicalPlane planeorientation = AnatomicalPlane::Axial,
+                                         ScalarType zPosition = 0,
+                                         bool frontside = true,
+                                         bool rotated = false,
+                                         bool top = true);
 
     /**
     * \brief Initialize plane by width and height in pixels, right-/down-vector
@@ -181,10 +210,16 @@ namespace mitk {
     *
     * The vectors are normalized and multiplied by the respective spacing before
     * they are set in the matrix.
+    *
+    * This overloaded version of InitializeStandardPlane() creates only righthanded
+    * coordinate orientations, unless spacing contains 1 or 3 negative entries.
+    *
     */
-    virtual void InitializeStandardPlane(ScalarType width, ScalarType height,
-      const Vector3D& rightVector, const Vector3D& downVector,
-      const Vector3D *spacing = nullptr);
+    virtual void InitializeStandardPlane(ScalarType width,
+                                         ScalarType height,
+                                         const Vector3D &rightVector,
+                                         const Vector3D &downVector,
+                                         const Vector3D *spacing = nullptr);
 
     /**
     * \brief Initialize plane by width and height in pixels,
@@ -193,10 +228,16 @@ namespace mitk {
     *
     * The vectors are normalized and multiplied by the respective spacing
     * before they are set in the matrix.
+    *
+    * This overloaded version of InitializeStandardPlane() creates only righthanded
+    * coordinate orientations, unless spacing contains 1 or 3 negative entries.
+    *
     */
-    virtual void InitializeStandardPlane(ScalarType width, ScalarType height,
-      const VnlVector& rightVector, const VnlVector& downVector,
-      const Vector3D * spacing = nullptr);
+    virtual void InitializeStandardPlane(ScalarType width,
+                                         ScalarType height,
+                                         const VnlVector &rightVector,
+                                         const VnlVector &downVector,
+                                         const Vector3D *spacing = nullptr);
 
     /**
     * \brief Initialize plane by right-/down-vector (itk) and spacing
@@ -206,8 +247,9 @@ namespace mitk {
     * respectively. Then, the vectors are normalized and multiplied by the
     * respective spacing before they are set in the matrix.
     */
-    virtual void InitializeStandardPlane(const Vector3D& rightVector,
-      const Vector3D& downVector, const Vector3D * spacing = nullptr);
+    virtual void InitializeStandardPlane(const Vector3D &rightVector,
+                                         const Vector3D &downVector,
+                                         const Vector3D *spacing = nullptr);
 
     /**
     * \brief Initialize plane by right-/down-vector (vnl) and spacing
@@ -217,32 +259,35 @@ namespace mitk {
     * respectively. Then, the vectors are normalized and multiplied by the
     * respective spacing before they are set in the matrix.
     */
-    virtual void InitializeStandardPlane(const VnlVector& rightVector,
-      const VnlVector& downVector, const Vector3D * spacing = nullptr);
+    virtual void InitializeStandardPlane(const VnlVector &rightVector,
+                                         const VnlVector &downVector,
+                                         const Vector3D *spacing = nullptr);
 
     /**
     * \brief Initialize plane by origin and normal (size is 1.0 mm in
     * all directions, direction of right-/down-vector valid but
     * undefined).
-    *
+    * \warning This function can only produce righthanded coordinate orientation, not lefthanded.
     */
-    virtual void InitializePlane(const Point3D& origin, const Vector3D& normal);
+    virtual void InitializePlane(const Point3D &origin, const Vector3D &normal);
 
     /**
     * \brief Initialize plane by right-/down-vector.
     *
     * \warning The vectors are set into the matrix as they are,
     * \em without normalization!
+    * This function creates a righthanded IndexToWorldTransform,
+    * only a negative thickness could still make it lefthanded.
     */
-    void SetMatrixByVectors(const VnlVector& rightVector,
-      const VnlVector& downVector, ScalarType thickness = 1.0);
+    void SetMatrixByVectors(const VnlVector &rightVector, const VnlVector &downVector, ScalarType thickness = 1.0);
 
     /**
-    * \brief Change \a transform so that the third column of the
-    * transform-martix is perpendicular to the first two columns
-    *
+    * \brief Check if matrix is a rotation matrix:
+    * - determinant is 1?
+    * - R*R^T is ID?
+    * Output warning otherwise.
     */
-    static void EnsurePerpendicularNormal(AffineTransform3D* transform);
+    static bool CheckRotationMatrix(AffineTransform3D *transform, double epsilon=1e-6);
 
     /**
     * \brief Normal of the plane
@@ -256,20 +301,20 @@ namespace mitk {
     */
     VnlVector GetNormalVnl() const;
 
-    virtual ScalarType SignedDistance(const Point3D& pt3d_mm) const;
+    virtual ScalarType SignedDistance(const Point3D &pt3d_mm) const;
 
     /**
     * \brief Calculates, whether a point is below or above the plane. There are two different
     *calculation methods, with or without consideration of the bounding box.
     */
-    virtual bool IsAbove(const Point3D& pt3d_mm, bool considerBoundingBox = false) const;
+    virtual bool IsAbove(const Point3D &pt3d_mm, bool considerBoundingBox = false) const;
 
     /**
     * \brief Distance of the point from the plane
     * (bounding-box \em not considered)
     *
     */
-    ScalarType DistanceFromPlane(const Point3D& pt3d_mm) const;
+    ScalarType DistanceFromPlane(const Point3D &pt3d_mm) const;
 
     /**
     * \brief Signed distance of the point from the plane
@@ -277,14 +322,14 @@ namespace mitk {
     *
     * > 0 : point is in the direction of the direction vector.
     */
-    inline ScalarType SignedDistanceFromPlane(const Point3D& pt3d_mm) const
+    inline ScalarType SignedDistanceFromPlane(const Point3D &pt3d_mm) const
     {
       ScalarType len = GetNormalVnl().two_norm();
 
       if (len == 0)
         return 0;
 
-      return (pt3d_mm - GetOrigin())*GetNormal() / len;
+      return (pt3d_mm - GetOrigin()) * GetNormal() / len;
     }
 
     /**
@@ -293,11 +338,7 @@ namespace mitk {
     *
     * Result is 0 if planes are not parallel.
     */
-    ScalarType DistanceFromPlane(const PlaneGeometry* plane) const
-    {
-      return fabs(SignedDistanceFromPlane(plane));
-    }
-
+    ScalarType DistanceFromPlane(const PlaneGeometry *plane) const { return fabs(SignedDistanceFromPlane(plane)); }
     /**
     * \brief Signed distance of the plane from another plane
     * (bounding-box \em not considered)
@@ -327,8 +368,7 @@ namespace mitk {
     * \return number of intersection points (0..2). First interection point (if existing)
     * is returned in \a lineFrom, second in \a lineTo.
     */
-    unsigned int IntersectWithPlane2D(const PlaneGeometry *plane,
-      Point2D &lineFrom, Point2D &lineTo) const;
+    unsigned int IntersectWithPlane2D(const PlaneGeometry *plane, Point2D &lineFrom, Point2D &lineTo) const;
 
     /**
     * \brief Calculate the angle between two planes
@@ -347,17 +387,18 @@ namespace mitk {
     /**
     * \brief Calculate intersection point between the plane and a line
     *
+    * \param line
     * \param intersectionPoint intersection point
     * \return \a true if \em unique intersection exists, i.e., if line
     * is \em not on or parallel to the plane
     */
-    bool IntersectionPoint(const Line3D &line,
-      Point3D &intersectionPoint) const;
+    bool IntersectionPoint(const Line3D &line, Point3D &intersectionPoint) const;
 
     /**
     * \brief Calculate line parameter of intersection point between the
     * plane and a line
     *
+    * \param line
     * \param t parameter of line: intersection point is
     * line.GetPoint()+t*line.GetDirection()
     * \return \a true if \em unique intersection exists, i.e., if line
@@ -388,7 +429,7 @@ namespace mitk {
     * \brief Returns whether the plane is on the plane
     * (bounding-box \em not considered)
     *
-    * @return true iff the normal vector of the planes point to the same or the exactly oposit direction and
+    * @return true if the normal vector of the planes point to the same or the exactly oposit direction and
     *  the distance of the planes is < eps
     *
     */
@@ -399,10 +440,10 @@ namespace mitk {
     */
     Point3D ProjectPointOntoPlane(const Point3D &pt) const;
 
-    virtual itk::LightObject::Pointer InternalClone() const override;
+    itk::LightObject::Pointer InternalClone() const override;
 
     /** Implements operation to re-orient the plane */
-    virtual void ExecuteOperation(Operation *operation) override;
+    void ExecuteOperation(Operation *operation) override;
 
     /**
     * \brief Project a 3D point given in mm (\a pt3d_mm) onto the 2D
@@ -444,8 +485,7 @@ namespace mitk {
     *
     * \return true projection was possible
     */
-    virtual bool Project(const mitk::Point3D &pt3d_mm,
-      mitk::Point3D &projectedPt3d_mm) const;
+    virtual bool Project(const mitk::Point3D &pt3d_mm, mitk::Point3D &projectedPt3d_mm) const;
 
     /**
     * \brief Project a 3D vector given in mm (\a vec3d_mm) onto the 2D
@@ -459,8 +499,7 @@ namespace mitk {
     * \sa Project(const mitk::Vector3D &vec3d_mm, mitk::Vector3D
     * &projectedVec3d_mm)
     */
-    virtual bool Map(const mitk::Point3D & atPt3d_mm,
-      const mitk::Vector3D &vec3d_mm, mitk::Vector2D &vec2d_mm) const;
+    virtual bool Map(const mitk::Point3D &atPt3d_mm, const mitk::Vector3D &vec3d_mm, mitk::Vector2D &vec2d_mm) const;
 
     /**
     * \brief Converts a 2D vector given in mm (\a vec2d_mm) relative to the
@@ -471,8 +510,7 @@ namespace mitk {
     * image) into a 2D vector given in mm (as required by this method), use
     * IndexToWorld.
     */
-    virtual void Map(const mitk::Point2D & atPt2d_mm,
-      const mitk::Vector2D &vec2d_mm, mitk::Vector3D &vec3d_mm) const;
+    virtual void Map(const mitk::Point2D &atPt2d_mm, const mitk::Vector2D &vec2d_mm, mitk::Vector3D &vec3d_mm) const;
 
     /**
     * \brief Project a 3D vector given in mm (\a vec3d_mm) onto the 2D
@@ -482,8 +520,9 @@ namespace mitk {
     *
     * \return true projection was possible
     */
-    virtual bool Project(const mitk::Point3D & atPt3d_mm,
-      const mitk::Vector3D &vec3d_mm, mitk::Vector3D &projectedVec3d_mm) const;
+    virtual bool Project(const mitk::Point3D &atPt3d_mm,
+                         const mitk::Vector3D &vec3d_mm,
+                         mitk::Vector3D &projectedVec3d_mm) const;
 
     /**
     * \brief Project a 3D vector given in mm (\a vec3d_mm) onto the 2D
@@ -498,11 +537,7 @@ namespace mitk {
     * (bounding-box \em not considered)
     *
     */
-    inline ScalarType Distance(const Point3D& pt3d_mm) const
-    {
-      return fabs(SignedDistance(pt3d_mm));
-    }
-
+    inline ScalarType Distance(const Point3D &pt3d_mm) const { return fabs(SignedDistance(pt3d_mm)); }
     /**
     * \brief Set the geometrical frame of reference in which this PlaneGeometry
     * is placed.
@@ -510,24 +545,26 @@ namespace mitk {
     * This would usually be the BaseGeometry of the underlying dataset, but
     * setting it is optional.
     */
-    void SetReferenceGeometry(mitk::BaseGeometry *geometry);
+    void SetReferenceGeometry(const mitk::BaseGeometry *geometry);
 
     /**
     * \brief Get the geometrical frame of reference for this PlaneGeometry.
     */
-    BaseGeometry *GetReferenceGeometry() const;
+    const BaseGeometry *GetReferenceGeometry() const;
     bool HasReferenceGeometry() const;
 
+    static std::vector< int > CalculateDominantAxes(mitk::AffineTransform3D::MatrixType::InternalMatrixType& rotation_matrix);
+
   protected:
     PlaneGeometry();
 
-    PlaneGeometry(const PlaneGeometry& other);
+    PlaneGeometry(const PlaneGeometry &other);
 
-    virtual ~PlaneGeometry();
+    ~PlaneGeometry() override;
 
-    virtual void PrintSelf(std::ostream &os, itk::Indent indent) const override;
+    void PrintSelf(std::ostream &os, itk::Indent indent) const override;
 
-    mitk::BaseGeometry *m_ReferenceGeometry;
+    const mitk::BaseGeometry *m_ReferenceGeometry;
 
     //##Documentation
     //## @brief PreSetSpacing
@@ -535,23 +572,24 @@ namespace mitk {
     //## These virtual function allows a different beahiour in subclasses.
     //## Do implement them in every subclass of BaseGeometry. If not needed, use
     //## {Superclass::PreSetSpacing();};
-    virtual void PreSetSpacing(const mitk::Vector3D& aSpacing) override{ Superclass::PreSetSpacing(aSpacing); };
-
+    void PreSetSpacing(const mitk::Vector3D &aSpacing) override { Superclass::PreSetSpacing(aSpacing); };
     //##Documentation
     //## @brief CheckBounds
     //##
     //## This function is called in SetBounds. Assertions can be implemented in this function (see PlaneGeometry.cpp).
     //## If you implement this function in a subclass, make sure, that all classes were your class inherits from
     //## have an implementation of CheckBounds
-    //## (e.g. inheritance BaseGeometry <- A <- B. Implementation of CheckBounds in class B needs implementation in A as well!)
-    virtual void CheckBounds(const BoundsArrayType& bounds) override;
+    //## (e.g. inheritance BaseGeometry <- A <- B. Implementation of CheckBounds in class B needs implementation in A as
+    // well!)
+    void CheckBounds(const BoundsArrayType &bounds) override;
 
     //##Documentation
     //## @brief CheckIndexToWorldTransform
     //##
-    //## This function is called in SetIndexToWorldTransform. Assertions can be implemented in this function (see PlaneGeometry.cpp).
+    //## This function is called in SetIndexToWorldTransform. Assertions can be implemented in this function (see
+    // PlaneGeometry.cpp).
     //## In Subclasses of BaseGeometry, implement own conditions or call Superclass::CheckBounds(bounds);.
-    virtual void CheckIndexToWorldTransform(mitk::AffineTransform3D* transform) override;
+    void CheckIndexToWorldTransform(mitk::AffineTransform3D *transform) override;
 
   private:
     /**
@@ -559,7 +597,6 @@ namespace mitk {
     * (bounding-box \em not considered)
     */
     virtual bool operator==(const PlaneGeometry *) const { return false; };
-
     /**
     * \brief Compares plane with another plane: \a false if IsOnPlane
     * (bounding-box \em not considered)
@@ -568,4 +605,4 @@ namespace mitk {
   };
 } // namespace mitk
 
-#endif /* PLANEGEOMETRY_H_HEADER_INCLUDED_C1C68A2C */
+#endif
