@@ -1,15 +1,15 @@
-/*=============================================================================
+/*============================================================================
 
   Library: CppMicroServices
 
-  Copyright (c) German Cancer Research Center,
-    Division of Medical and Biological Informatics
+  Copyright (c) German Cancer Research Center (DKFZ)
+  All rights reserved.
 
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
-    http://www.apache.org/licenses/LICENSE-2.0
+    https://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,7 +17,7 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-=============================================================================*/
+============================================================================*/
 
 #include "usLDAPExpr_p.h"
 
@@ -49,7 +49,7 @@ static const std::string& WILDCARD_STRING()
   return s;
 }
 
-static const std::string& NULLQ()
+static const std::string& nullptrQ()
 {
   static std::string s = "Null query";
   return s;
@@ -86,48 +86,6 @@ bool stricomp(const std::string::value_type& v1, const std::string::value_type&
   return ::tolower(v1) == ::tolower(v2);
 }
 
-//! Contains the current parser position and parsing utility methods.
-class LDAPExpr::ParseState
-{
-
-private:
-
-  std::size_t m_pos;
-  std::string m_str;
-
-public:
-
-  ParseState(const std::string &str);
-
-  //! Move m_pos to remove the prefix \a pre
-  bool prefix(const std::string &pre);
-
-  /** Peek a char at m_pos
-  \note If index out of bounds, throw exception
-  */
-  LDAPExpr::Byte peek();
-
-  //! Increment m_pos by n
-  void skip(int n);
-
-  //! return string from m_pos until the end
-  std::string rest() const;
-
-  //! Move m_pos until there's no spaces
-  void skipWhite();
-
-  //! Get string until special chars. Move m_pos
-  std::string getAttributeName();
-
-  //! Get string and convert * to WILDCARD
-  std::string getAttributeValue();
-
-  //! Throw InvalidSyntaxException exception
-  void error(const std::string &m) const;
-
-};
-
-
 class LDAPExprData : public SharedData
 {
 public:
@@ -453,7 +411,7 @@ bool LDAPExpr::Compare( const Any& obj, int op, const std::string& s ) const
     else if (objType == typeid(float))
     {
       errno = 0;
-      char* endptr = 0;
+      char* endptr = nullptr;
       double sFloat = strtod(s.c_str(), &endptr);
       if ((errno == ERANGE && (sFloat == 0 || sFloat == HUGE_VAL || sFloat == -HUGE_VAL)) ||
           (errno != 0 && sFloat == 0) || endptr == s.c_str())
@@ -477,7 +435,7 @@ bool LDAPExpr::Compare( const Any& obj, int op, const std::string& s ) const
     else if (objType == typeid(double))
     {
       errno = 0;
-      char* endptr = 0;
+      char* endptr = nullptr;
       double sDouble = strtod(s.c_str(), &endptr);
       if ((errno == ERANGE && (sDouble == 0 || sDouble == HUGE_VAL || sDouble == -HUGE_VAL)) ||
           (errno != 0 && sDouble == 0) || endptr == s.c_str())
@@ -520,7 +478,7 @@ template<typename T>
 bool LDAPExpr::CompareIntegralType(const Any& obj, const int op, const std::string& s) const
 {
   errno = 0;
-  char* endptr = 0;
+  char* endptr = nullptr;
   long longInt = strtol(s.c_str(), &endptr, 10);
   if ((errno == ERANGE && (longInt == std::numeric_limits<long>::max() || longInt == std::numeric_limits<long>::min())) ||
        (errno != 0 && longInt == 0) || endptr == s.c_str())
@@ -743,7 +701,7 @@ LDAPExpr::ParseState::ParseState( const std::string& str )
 {
   if (str.empty())
   {
-    error(LDAPExprConstants::NULLQ());
+    error(LDAPExprConstants::nullptrQ());
   }
 
   m_str = str;
