@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "mitkTestingMacros.h"
 #include "mitkNavigationData.h"
@@ -212,7 +208,7 @@ static void TestWrongInputs()
   {
     nd->CopyInformation(nullptr);
   }
-  catch(itk::ExceptionObject e)
+  catch(itk::ExceptionObject&)
   {
     success = true;
   }
@@ -225,7 +221,7 @@ static void TestWrongInputs()
   {
     nd->Graft(nullptr);
   }
-  catch(itk::ExceptionObject e)
+  catch(itk::ExceptionObject&)
   {
     success = true;
   }
@@ -264,7 +260,7 @@ static void SetupNaviDataTests()
 
   // set quaternion to quaternion equivalent
   // values calculated with javascript at
-  // http://www.euclideanspace.com/maths/geometry/rotations/conversions/matrixToQuaternion/
+  // https://www.euclideanspace.com/maths/geometry/rotations/conversions/matrixToQuaternion/
   quaternion = mitk::Quaternion(0, 0, 0.7071067811865475, 0.7071067811865476);
 
   // a more realistic quaternion from real tracking data
@@ -329,7 +325,7 @@ static mitk::AffineTransform3D::Pointer CreateAffineTransform(mitk::Matrix3D rot
 /**
  * Test if NavigationData::GetInverse returns the correct inverse
  */
-static void TestInverse()
+/*static void TestInverse()
 {
   SetupNaviDataTests();
   mitk::NavigationData::Pointer nd = CreateNavidata(quaternion, offsetPoint);
@@ -384,7 +380,7 @@ static void TestInverse()
   mitk::NavigationData::Pointer ndInverse2 = nd2->GetInverse();
   MITK_TEST_CONDITION(mitk::Equal(nd2->GetOrientation(),referenceQuaternion),"Testing if the method GetInverse() modifies the data which should never happen!");
   MITK_TEST_CONDITION(mitk::Equal(ndInverse2->GetOrientation(),referenceQuaternion.inverse()),"Testing if the Qrientation was inverted correctly with the realistic quaternion");
-}
+}*/
 
 /**
  * Test if the original orientation and position are retained after inverting two times.
@@ -412,7 +408,7 @@ static void TestInverseError()
   quaternion.fill(0);
   nd->SetOrientation(quaternion);
 
-  MITK_TEST_FOR_EXCEPTION(mitk::Exception&, nd->GetInverse());
+  MITK_TEST_FOR_EXCEPTION(mitk::Exception, nd->GetInverse());
 }
 
 /**
@@ -465,7 +461,7 @@ static void TestAffineConstructorErrorTransposedNotInverse()
   rotation[1][0] = 2; // this matrix has determinant = 1 (triangular matrix with ones in diagonal) but transposed != inverse
   mitk::AffineTransform3D::Pointer affineTransform3D = CreateAffineTransform(rotation, offsetVector);
 
-  MITK_TEST_FOR_EXCEPTION(mitk::Exception&, mitk::NavigationData::New(affineTransform3D));
+  MITK_TEST_FOR_EXCEPTION(mitk::Exception, mitk::NavigationData::New(affineTransform3D));
 }
 
 /**
@@ -479,7 +475,7 @@ static void TestAffineConstructorErrorDeterminantNonEqualOne()
   rotation[0][0] = 2; // determinant for diagonal matrices is product of diagonal elements => det = 2
   mitk::AffineTransform3D::Pointer affineTransform3D = CreateAffineTransform(rotation, offsetVector);
 
-  MITK_TEST_FOR_EXCEPTION(mitk::Exception&, mitk::NavigationData::New(affineTransform3D));
+  MITK_TEST_FOR_EXCEPTION(mitk::Exception, mitk::NavigationData::New(affineTransform3D));
 }
 
 
