@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "mitkOptitrackTrackingTool.h"
 
@@ -27,7 +23,7 @@ See LICENSE.txt or http://www.mitk.org for details.
 // Constructor
 //=======================================================
 mitk::OptitrackTrackingTool::OptitrackTrackingTool()
-  :  mitk::InternalTrackingTool(),
+  :  mitk::TrackingTool(),
     m_ID(-1)
 {
   MITK_DEBUG << "Creating OptitrackTrackingTool Object";
@@ -64,7 +60,7 @@ bool mitk::OptitrackTrackingTool::SetToolByFileName(std::string nameFile)
 
   // Open the file
   FILE* calib_file = fopen(this->m_fileConfiguration.c_str(),"r");
-  if (calib_file == NULL)
+  if (calib_file == nullptr)
   {
     MITK_INFO << "Error using opening file";
     mitkThrowException(mitk::IGTException) << "Cannot open configuration file";
@@ -496,7 +492,7 @@ void mitk::OptitrackTrackingTool::updateTool()
 // Constructor
 //=======================================================
 mitk::OptitrackTrackingTool::OptitrackTrackingTool()
-  :  mitk::InternalTrackingTool(),
+  :  mitk::TrackingTool(),
     m_ID(-1)
 {
   MITK_WARN("IGT") << "Error: " << mitk::OptitrackErrorMessages::GetOptitrackErrorMessage(100);
@@ -513,7 +509,7 @@ mitk::OptitrackTrackingTool::~OptitrackTrackingTool()
 //=======================================================
 // SetToolByFileName
 //=======================================================
-bool mitk::OptitrackTrackingTool::SetToolByFileName(std::string nameFile)
+bool mitk::OptitrackTrackingTool::SetToolByFileName(std::string)
 {
   MITK_WARN("IGT") << "Error: " << mitk::OptitrackErrorMessages::GetOptitrackErrorMessage(100);
   return false;
@@ -540,7 +536,7 @@ bool mitk::OptitrackTrackingTool::DeleteTrackable()
 //=======================================================
 // SetPosition
 //=======================================================
-void mitk::OptitrackTrackingTool::SetPosition(mitk::Point3D position, ScalarType eps)
+void mitk::OptitrackTrackingTool::SetPosition(mitk::Point3D, ScalarType)
 {
   MITK_WARN("IGT") << "Error: " << mitk::OptitrackErrorMessages::GetOptitrackErrorMessage(100);
 }
@@ -548,7 +544,7 @@ void mitk::OptitrackTrackingTool::SetPosition(mitk::Point3D position, ScalarType
 //=======================================================
 // SetOrientation
 //=======================================================
-void mitk::OptitrackTrackingTool::SetOrientation(mitk::Quaternion orientation, ScalarType eps)
+void mitk::OptitrackTrackingTool::SetOrientation(mitk::Quaternion, ScalarType)
 {
   MITK_WARN("IGT") << "Error: " << mitk::OptitrackErrorMessages::GetOptitrackErrorMessage(100);
 }
@@ -556,7 +552,7 @@ void mitk::OptitrackTrackingTool::SetOrientation(mitk::Quaternion orientation, S
 //=======================================================
 // GetPosition
 //=======================================================
-void mitk::OptitrackTrackingTool::GetPosition(mitk::Point3D& positionOutput) const
+void mitk::OptitrackTrackingTool::GetPosition(mitk::Point3D&) const
 {
   MITK_WARN("IGT") << "Error: " << mitk::OptitrackErrorMessages::GetOptitrackErrorMessage(100);
 }
@@ -564,7 +560,7 @@ void mitk::OptitrackTrackingTool::GetPosition(mitk::Point3D& positionOutput) con
 //=======================================================
 // GetOrientation
 //=======================================================
-void mitk::OptitrackTrackingTool::GetOrientation(mitk::Quaternion& orientation) const
+void mitk::OptitrackTrackingTool::GetOrientation(mitk::Quaternion&) const
 {
   MITK_WARN("IGT") << "Error: " << mitk::OptitrackErrorMessages::GetOptitrackErrorMessage(100);
 }
@@ -617,7 +613,7 @@ float mitk::OptitrackTrackingTool::GetTrackingError() const
 //=======================================================
 // SetTrackingError
 //=======================================================
-void mitk::OptitrackTrackingTool::SetTrackingError(float error)
+void mitk::OptitrackTrackingTool::SetTrackingError(float)
 {
   MITK_WARN("IGT") << "Error: " << mitk::OptitrackErrorMessages::GetOptitrackErrorMessage(100);
 }
@@ -625,7 +621,7 @@ void mitk::OptitrackTrackingTool::SetTrackingError(float error)
 //=======================================================
 // SetDataValid
 //=======================================================
-void mitk::OptitrackTrackingTool::SetDataValid(bool validate)
+void mitk::OptitrackTrackingTool::SetDataValid(bool)
 {
   MITK_WARN("IGT") << "Error: " << mitk::OptitrackErrorMessages::GetOptitrackErrorMessage(100);
 }
