@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "QmitkIGTPlayerWidget.h"
 
@@ -25,7 +21,8 @@ See LICENSE.txt or http://www.mitk.org for details.
 #include <mitkNavigationToolStorageDeserializer.h>
 #include <mitkNavigationToolStorageSerializer.h>
 #include <mitkIGTException.h>
-#include "mitkNavigationDataReaderXML.h"
+#include <mitkIOUtil.h>
+#include <QmitkIGTCommonHelper.h>
 
 //qt headers
 #include <qfiledialog.h>
@@ -87,7 +84,7 @@ bool QmitkIGTPlayerWidget::CheckInputFileValid()
   // check if file exists
   if(!file.exists())
   {
-    QMessageBox::warning(NULL, "IGTPlayer: Error", "No valid input file was loaded. Please load input file first!");
+    QMessageBox::warning(nullptr, "IGTPlayer: Error", "No valid input file was loaded. Please load input file first!");
     return false;
   }
 
@@ -158,15 +155,14 @@ void QmitkIGTPlayerWidget::OnPlayButtonClicked(bool checked)
         mitk::NavigationDataSet::Pointer navigationDataSet;
         try
         {
-          mitk::NavigationDataReaderXML::Pointer reader = mitk::NavigationDataReaderXML::New();
-          navigationDataSet = reader->Read(m_CmpFilename.toStdString());
+          navigationDataSet = dynamic_cast<mitk::NavigationDataSet*> (mitk::IOUtil::Load(m_CmpFilename.toStdString())[0].GetPointer());
         }
-        catch(mitk::IGTException)
+        catch(const mitk::IGTException&)
         {
           std::string errormessage = "Error during start playing. Invalid or wrong file?";
-          QMessageBox::warning(NULL, "IGTPlayer: Error", errormessage.c_str());
+          QMessageBox::warning(nullptr, "IGTPlayer: Error", errormessage.c_str());
           m_Controls->playPushButton->setChecked(false);
-          m_RealTimePlayer = NULL;
+          m_RealTimePlayer = nullptr;
           return;
         }
 
@@ -178,12 +174,12 @@ void QmitkIGTPlayerWidget::OnPlayButtonClicked(bool checked)
           {
             m_RealTimePlayer->StartPlaying();
           }
-          catch(mitk::IGTException)
+          catch(const mitk::IGTException&)
           {
             std::string errormessage = "Error during start playing. Invalid or wrong file?";
-            QMessageBox::warning(NULL, "IGTPlayer: Error", errormessage.c_str());
+            QMessageBox::warning(nullptr, "IGTPlayer: Error", errormessage.c_str());
             m_Controls->playPushButton->setChecked(false);
-            m_RealTimePlayer = NULL;
+            m_RealTimePlayer = nullptr;
             return;
           }
         }
@@ -194,12 +190,12 @@ void QmitkIGTPlayerWidget::OnPlayButtonClicked(bool checked)
           {
             m_SequentialPlayer->SetNavigationDataSet(navigationDataSet);
           }
-          catch(mitk::IGTException)
+          catch(const mitk::IGTException&)
           {
             std::string errormessage = "Error during start playing. Invalid or wrong file type?";
-            QMessageBox::warning(NULL, "IGTPlayer: Error", errormessage.c_str());
+            QMessageBox::warning(nullptr, "IGTPlayer: Error", errormessage.c_str());
             m_Controls->playPushButton->setChecked(false);
-            m_RealTimePlayer = NULL;
+            m_RealTimePlayer = nullptr;
             return;
           }
 
@@ -376,20 +372,13 @@ const mitk::PointSet::Pointer QmitkIGTPlayerWidget::GetNavigationDatasPointSet()
 
   if( (isRealTimeMode && m_RealTimePlayer.IsNotNull()) || (isSequentialMode && m_SequentialPlayer.IsNotNull()))
   {
-    int numberOfOutputs = 0;
-
-    if(isRealTimeMode)
-      numberOfOutputs = m_RealTimePlayer->GetNumberOfOutputs();
-    else if(isSequentialMode)
-      numberOfOutputs = m_SequentialPlayer->GetNumberOfOutputs();
-
     for(unsigned int i=0; i < m_RealTimePlayer->GetNumberOfOutputs(); ++i)
     {
       mitk::NavigationData::PositionType position;
 
       if(isRealTimeMode)
         position = m_RealTimePlayer->GetOutput(i)->GetPosition();
-      else if(isSequentialMode)
+      else
         position = m_SequentialPlayer->GetOutput(i)->GetPosition();
 
       pointType[0] = position[0];
@@ -405,7 +394,7 @@ const mitk::PointSet::Pointer QmitkIGTPlayerWidget::GetNavigationDatasPointSet()
 
 const mitk::PointSet::PointType QmitkIGTPlayerWidget::GetNavigationDataPoint(unsigned int index)
 {
-  if( index > this->GetNumberOfTools() || index < 0 )
+  if( index > this->GetNumberOfTools() )
     throw std::out_of_range("Tool Index out of range!");
 
   PlaybackMode currentMode = this->GetCurrentPlaybackMode();
@@ -446,13 +435,14 @@ m_SequentialPlayer = player;
 
 void QmitkIGTPlayerWidget::OnOpenFileButtonPressed()
 {
-  QString filename = QFileDialog::getOpenFileName(this, "Load tracking data", QDir::currentPath(),"XML files (*.xml)");
+  QString filename = QFileDialog::getOpenFileName(this, "Load tracking data", QmitkIGTCommonHelper::GetLastFileLoadPath(),"XML files (*.xml)");
   QFile file(filename);
 
+  QmitkIGTCommonHelper::SetLastFileLoadPathByFileName(filename);
   // if something went wrong or user pressed cancel in the save dialog
   if ( filename.isEmpty()  || ! file.exists() )
   {
-    QMessageBox::warning(NULL, "Warning", QString("Please enter valid path. Using previous path again."));
+    QMessageBox::warning(nullptr, "Warning", QString("Please enter valid path. Using previous path again."));
     return;
   }
 
@@ -464,8 +454,7 @@ void QmitkIGTPlayerWidget::OnOpenFileButtonPressed()
 
   emit SignalInputFileChanged();
 
-  mitk::NavigationDataReaderInterface::Pointer navigationDataReader = mitk::NavigationDataReaderXML::New().GetPointer();
-  mitk::NavigationDataSet::Pointer navigationDataSet = navigationDataReader->Read(m_CmpFilename.toStdString());
+  mitk::NavigationDataSet::Pointer navigationDataSet = dynamic_cast<mitk::NavigationDataSet*> (mitk::IOUtil::Load(m_CmpFilename.toStdString())[0].GetPointer());
   m_RealTimePlayer->SetNavigationDataSet(navigationDataSet);
   m_SequentialPlayer->SetNavigationDataSet(navigationDataSet);
 
@@ -488,7 +477,7 @@ void QmitkIGTPlayerWidget::OnGoToBegin()
   if(this->GetCurrentPlaybackMode() == RealTimeMode && m_RealTimePlayer.IsNotNull())
   {
     m_RealTimePlayer->StopPlaying();
-    m_RealTimePlayer = NULL;  // set player to NULL so it can be initialized again if playback is called afterwards
+    m_RealTimePlayer = nullptr;  // set player to nullptr so it can be initialized again if playback is called afterwards
   }
 
   m_StartTime = -1;  // set starttime back
@@ -557,9 +546,9 @@ void QmitkIGTPlayerWidget::OnSliderReleased()
 {
   int currentSliderValue = m_Controls->samplePositionHorizontalSlider->value(); // current slider value selected through user movement
 
-  if(currentSliderValue > m_CurrentSequentialPointNumber) // at the moment only forward scrolling is possible
+  if(currentSliderValue > static_cast<int>(m_CurrentSequentialPointNumber)) // at the moment only forward scrolling is possible
   {
-    unsigned int snapshotNumber = currentSliderValue;
+    auto snapshotNumber = static_cast<unsigned int>(currentSliderValue);
     m_SequentialPlayer->GoToSnapshot(snapshotNumber); // move player to selected snapshot
     m_CurrentSequentialPointNumber = currentSliderValue;
     m_Controls->sampleLCDNumber->display(currentSliderValue); // update lcdnumber in widget
