@@ -1,21 +1,17 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-#ifndef QMITKNAVIGATIONDATAPLAYERCONTROLWIDGET_H
-#define QMITKNAVIGATIONDATAPLAYERCONTROLWIDGET_H
+#ifndef QmitkNavigationDataPlayerControlWidget_h
+#define QmitkNavigationDataPlayerControlWidget_h
 
 #include <QWidget>
 #include "mitkNavigationDataPlayer.h"
@@ -44,8 +40,8 @@ protected slots:
   void OnUpdate();
 
 public:
-  explicit QmitkNavigationDataPlayerControlWidget(QWidget *parent = 0);
-  ~QmitkNavigationDataPlayerControlWidget();
+  explicit QmitkNavigationDataPlayerControlWidget(QWidget *parent = nullptr);
+  ~QmitkNavigationDataPlayerControlWidget() override;
 
   void SetPlayer(mitk::NavigationDataPlayer::Pointer player);
 
@@ -59,4 +55,4 @@ private:
   Ui::QmitkNavigationDataPlayerControlWidget *ui;
 };
 
-#endif // QMITKNAVIGATIONDATAPLAYERCONTROLWIDGET_H
+#endif
