@@ -1,21 +1,17 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-#ifndef QMITKNAVIGATIONDATASEQUENTIALPLAYERCONTROLWIDGET_H
-#define QMITKNAVIGATIONDATASEQUENTIALPLAYERCONTROLWIDGET_H
+#ifndef QmitkNavigationDataSequentialPlayerControlWidget_h
+#define QmitkNavigationDataSequentialPlayerControlWidget_h
 
 #include <QWidget>
 #include "mitkNavigationDataSequentialPlayer.h"
@@ -45,8 +41,8 @@ protected slots:
   void OnUpdateIntervalChanged(int);
 
 public:
-  explicit QmitkNavigationDataSequentialPlayerControlWidget(QWidget *parent = 0);
-  ~QmitkNavigationDataSequentialPlayerControlWidget();
+  explicit QmitkNavigationDataSequentialPlayerControlWidget(QWidget *parent = nullptr);
+  ~QmitkNavigationDataSequentialPlayerControlWidget() override;
 
   void SetPlayer(mitk::NavigationDataSequentialPlayer::Pointer player);
 
@@ -61,4 +57,4 @@ private:
   Ui::QmitkNavigationDataSequentialPlayerControlWidget *ui;
 };
 
-#endif // QMITKNAVIGATIONDATASEQUENTIALPLAYERCONTROLWIDGET_H
+#endif
