@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "mitkImageStatisticsCalculator.h"
 #include "itkMultiGaussianImageSource.h"
@@ -26,6 +22,11 @@ See LICENSE.txt or http://www.mitk.org for details.
 #include <itkDOMNode.h>
 #include <itkDOMReader.h>
 
+#include <mitkHotspotMaskGenerator.h>
+#include <mitkImageMaskGenerator.h>
+
+#include <mitkIOUtil.h>
+
 /**
  \section hotspotCalculationTestCases Testcases
 
@@ -448,9 +449,8 @@ struct mitkImageStatisticsHotspotTestClass
 
     Uses ImageStatisticsCalculator to find a hotspot in a defined ROI within the given image.
   */
-  static mitk::ImageStatisticsCalculator::Statistics CalculateStatistics(mitk::Image* image, const Parameters& testParameters,  unsigned int label)
+  static mitk::ImageStatisticsContainer::ImageStatisticsObject CalculateStatistics(mitk::Image* image, const Parameters& testParameters,  unsigned int label)
   {
-    mitk::ImageStatisticsCalculator::Statistics result;
     const unsigned int Dimension = 3;
     typedef itk::Image<unsigned short, Dimension> MaskImageType;
     MaskImageType::Pointer mask = MaskImageType::New();
@@ -460,7 +460,7 @@ struct mitkImageStatisticsHotspotTestClass
     MaskImageType::IndexType start;
 
     mitk::ImageStatisticsCalculator::Pointer statisticsCalculator = mitk::ImageStatisticsCalculator::New();
-    statisticsCalculator->SetImage(image);
+    statisticsCalculator->SetInputImage(image);
     mitk::Image::Pointer mitkMaskImage;
 
     if((testParameters.m_MaxIndexX[label] > testParameters.m_MinIndexX[label] && testParameters.m_MinIndexX[label] >= 0) &&
@@ -509,35 +509,49 @@ struct mitkImageStatisticsHotspotTestClass
         }
       }
 
-      MITK_DEBUG << "Masking mode has set to image";
       mitk::CastToMitkImage(mask, mitkMaskImage);
-      statisticsCalculator->SetImageMask(mitkMaskImage);
-      statisticsCalculator->SetMaskingModeToImage();
+      mitk::ImageMaskGenerator::Pointer imgMaskGen = mitk::ImageMaskGenerator::New();
+      imgMaskGen->SetInputImage(image);
+      imgMaskGen->SetImageMask(mitkMaskImage);
+
+      mitk::HotspotMaskGenerator::Pointer hotspotMaskGen = mitk::HotspotMaskGenerator::New();
+      hotspotMaskGen->SetInputImage(image);
+      hotspotMaskGen->SetLabel(testParameters.m_Label[label]);
+      hotspotMaskGen->SetMask(imgMaskGen.GetPointer());
+      hotspotMaskGen->SetHotspotRadiusInMM(testParameters.m_HotspotRadiusInMM);
+      if(testParameters.m_EntireHotspotInImage == 1)
+      {
+        MITK_INFO << "Hotspot must be completly inside image";
+        hotspotMaskGen->SetHotspotMustBeCompletelyInsideImage(true);
+      }
+      else
+      {
+        MITK_INFO << "Hotspot must not be completly inside image";
+        hotspotMaskGen->SetHotspotMustBeCompletelyInsideImage(false);
+      }
+
+      statisticsCalculator->SetMask(hotspotMaskGen.GetPointer());
+      MITK_DEBUG << "Masking is set to hotspot+image mask";
     }
     else
     {
-      MITK_DEBUG << "Masking mode has set to none";
-      statisticsCalculator->SetMaskingModeToNone();
+      mitk::HotspotMaskGenerator::Pointer hotspotMaskGen = mitk::HotspotMaskGenerator::New();
+      hotspotMaskGen->SetInputImage(image);
+      hotspotMaskGen->SetHotspotRadiusInMM(testParameters.m_HotspotRadiusInMM);
+      if(testParameters.m_EntireHotspotInImage == 1)
+      {
+        MITK_INFO << "Hotspot must be completly inside image";
+        hotspotMaskGen->SetHotspotMustBeCompletelyInsideImage(true);
+      }
+      else
+      {
+        MITK_INFO << "Hotspot must not be completly inside image";
+        hotspotMaskGen->SetHotspotMustBeCompletelyInsideImage(false);
+      }
+      MITK_DEBUG << "Masking is set to hotspot only";
     }
 
-    statisticsCalculator->SetHotspotRadiusInMM(testParameters.m_HotspotRadiusInMM);
-    statisticsCalculator->SetCalculateHotspot(true);
-
-    if(testParameters.m_EntireHotspotInImage == 1)
-    {
-      MITK_INFO << "Hotspot must be completly inside image";
-      statisticsCalculator->SetHotspotMustBeCompletlyInsideImage(true);
-    }
-    else
-    {
-      MITK_INFO << "Hotspot must not be completly inside image";
-      statisticsCalculator->SetHotspotMustBeCompletlyInsideImage(false);
-    }
-
-    statisticsCalculator->ComputeStatistics();
-    result = statisticsCalculator->GetStatistics(0, label);
-
-    return result;
+    return statisticsCalculator->GetStatistics()->GetStatisticsForTimeStep(0);
   }
 
   static void ValidateStatisticsItem(const std::string& label, double testvalue, double reference, double tolerance)
@@ -571,20 +585,24 @@ struct mitkImageStatisticsHotspotTestClass
 
     Checks validness of all statistics aspects. Lets test fail if any aspect is not sufficiently equal.
   */
-  static void ValidateStatistics(const mitk::ImageStatisticsCalculator::Statistics& statistics, const Parameters& testParameters, unsigned int label)
+  static void ValidateStatistics(const mitk::ImageStatisticsContainer::ImageStatisticsObject hotspotStatistics, const Parameters& testParameters, unsigned int label)
   {
     // check all expected test result against actual results
     double eps = 0.25; // value above the largest tested difference
 
-    ValidateStatisticsItem("Hotspot mean", statistics.GetHotspotStatistics().GetMean(), testParameters.m_HotspotMean[label], eps);
-    ValidateStatisticsItem("Hotspot maximum", statistics.GetHotspotStatistics().GetMax(), testParameters.m_HotspotMax[label], eps);
-    ValidateStatisticsItem("Hotspot minimum", statistics.GetHotspotStatistics().GetMin(), testParameters.m_HotspotMin[label], eps);
+    auto mean = hotspotStatistics.GetValueConverted<mitk::ImageStatisticsContainer::RealType>(mitk::ImageStatisticsConstants::MEAN());
+    auto max = hotspotStatistics.GetValueConverted<mitk::ImageStatisticsContainer::RealType>(mitk::ImageStatisticsConstants::MAXIMUM());
+    auto min = hotspotStatistics.GetValueConverted<mitk::ImageStatisticsContainer::RealType>(mitk::ImageStatisticsConstants::MINIMUM());
+
+    ValidateStatisticsItem("Hotspot mean", mean, testParameters.m_HotspotMean[label], eps);
+    ValidateStatisticsItem("Hotspot maximum", max, testParameters.m_HotspotMax[label], eps);
+    ValidateStatisticsItem("Hotspot minimum", min, testParameters.m_HotspotMin[label], eps);
 
     vnl_vector<int> referenceHotspotCenterIndex; referenceHotspotCenterIndex.set_size(3);
     referenceHotspotCenterIndex[0] = testParameters.m_HotspotIndexX[label];
     referenceHotspotCenterIndex[1] = testParameters.m_HotspotIndexY[label];
     referenceHotspotCenterIndex[2] = testParameters.m_HotspotIndexZ[label];
-    ValidateStatisticsItem("Hotspot center position", statistics.GetHotspotStatistics().GetHotspotIndex(), referenceHotspotCenterIndex);
+    // ValidateStatisticsItem("Hotspot center position", statistics.GetHotspotStatistics().GetHotspotIndex(), referenceHotspotCenterIndex); TODO: new image statistics calculator does not give hotspot position
 
     // TODO we do not test minimum/maximum positions within the peak/hotspot region, because
     //      these positions are not unique, i.e. there are multiple valid minima/maxima positions.
@@ -609,7 +627,7 @@ int mitkImageStatisticsHotspotTest(int argc, char* argv[])
 
       for(unsigned int label = 0; label < parameters.m_NumberOfLabels; ++label)
       {
-        mitk::ImageStatisticsCalculator::Statistics statistics = mitkImageStatisticsHotspotTestClass::CalculateStatistics(image, parameters, label);
+        mitk::ImageStatisticsContainer::ImageStatisticsObject statistics = mitkImageStatisticsHotspotTestClass::CalculateStatistics(image, parameters, label);
 
         mitkImageStatisticsHotspotTestClass::ValidateStatistics(statistics, parameters, label);
         std::cout << std::endl;
