@@ -1,21 +1,17 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-#ifndef __mitkOpenCLActivator_h
-#define __mitkOpenCLActivator_h
+#ifndef mitkOpenCLActivator_h
+#define mitkOpenCLActivator_h
 
 #include "mitkOclResourceServiceImpl_p.h"
 
@@ -38,7 +34,7 @@ class US_ABI_LOCAL OpenCLActivator : public us::ModuleActivator
 {
 private:
 
-  std::auto_ptr<OclResourceServiceImpl> m_ResourceService;
+  std::unique_ptr<OclResourceServiceImpl> m_ResourceService;
 
 public:
   /** @brief Load module context */
@@ -51,4 +47,4 @@ public:
 
 
 
-#endif // __mitkOpenCLActivator_h
+#endif
