@@ -1,21 +1,17 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-#ifndef mitkCropOpenCVImageFilter_h
-#define mitkCropOpenCVImageFilter_h
+#ifndef mitkAbstractOpenCVImageFilter_h
+#define mitkAbstractOpenCVImageFilter_h
 
 #include <MitkOpenCVVideoSupportExports.h>
 
@@ -65,4 +61,4 @@ protected:
 
 } // namespace mitk
 
-#endif // mitkCropOpenCVImageFilter_h
+#endif
