@@ -1,25 +1,20 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "SelectionView.h"
 
 const std::string SelectionView::VIEW_ID = "org.mitk.views.selectionview";
 
-SelectionView::SelectionView()
-  : m_Parent(nullptr)
+SelectionView::SelectionView() : m_Parent(nullptr)
 {
 }
 
@@ -45,9 +40,8 @@ void SelectionView::CreateQtPartControl(QWidget *parent)
   m_Controls.m_SelectionList->setCurrentRow(0);
 
   m_Parent->setEnabled(true);
-
 }
 
-void SelectionView::SetFocus ()
+void SelectionView::SetFocus()
 {
 }
