@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "QmitkToolGUI.h"
 
@@ -20,9 +16,7 @@ See LICENSE.txt or http://www.mitk.org for details.
 
 QmitkToolGUI::~QmitkToolGUI()
 {
-  m_ReferenceCountLock.Lock();
   m_ReferenceCount = 0; // otherwise ITK will complain in LightObject's destructor
-  m_ReferenceCountLock.Unlock();
 }
 
 void QmitkToolGUI::Register() const
@@ -40,10 +34,9 @@ void QmitkToolGUI::SetReferenceCount(int)
   // empty on purpose, just don't let ITK handle calls to SetReferenceCount()
 }
 
-void QmitkToolGUI::SetTool( mitk::Tool* tool )
+void QmitkToolGUI::SetTool(mitk::Tool *tool)
 {
   m_Tool = tool;
 
-  emit( NewToolAssociated(tool) );
+  emit(NewToolAssociated(tool));
 }
-
