@@ -1,27 +1,23 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "mitkCreateDistanceImageFromSurfaceFilter.h"
 #include "mitkImageCast.h"
 
-#include "vtkSmartPointer.h"
-#include "vtkDoubleArray.h"
 #include "vtkCellArray.h"
 #include "vtkCellData.h"
+#include "vtkDoubleArray.h"
 #include "vtkPolyData.h"
+#include "vtkSmartPointer.h"
 
 #include "itkImageRegionIteratorWithIndex.h"
 #include "itkNeighborhoodIterator.h"
@@ -34,8 +30,8 @@ void mitk::CreateDistanceImageFromSurfaceFilter::CreateEmptyDistanceImage()
   DistanceImageType::PointType minPointInWorldCoordinates, maxPointInWorldCoordinates;
   DistanceImageType::IndexType minPointInIndexCoordinates, maxPointInIndexCoordinates;
 
-  DetermineBounds( minPointInWorldCoordinates, maxPointInWorldCoordinates,
-                   minPointInIndexCoordinates, maxPointInIndexCoordinates );
+  DetermineBounds(
+    minPointInWorldCoordinates, maxPointInWorldCoordinates, minPointInIndexCoordinates, maxPointInIndexCoordinates);
 
   // Calculate the extent of the region that contains all given points in MM.
   // To do this, we take the difference between the maximal and minimal
@@ -44,7 +40,8 @@ void mitk::CreateDistanceImageFromSurfaceFilter::CreateEmptyDistanceImage()
   Vector3D extentMM;
   for (unsigned int dim = 0; dim < 3; ++dim)
   {
-    extentMM[dim] = (std::abs(maxPointInIndexCoordinates[dim] - minPointInIndexCoordinates[dim])) * m_ReferenceImage->GetSpacing()[dim];
+    extentMM[dim] = (std::abs(maxPointInIndexCoordinates[dim] - minPointInIndexCoordinates[dim])) *
+                    m_ReferenceImage->GetSpacing()[dim];
   }
 
   /*
@@ -54,8 +51,8 @@ void mitk::CreateDistanceImageFromSurfaceFilter::CreateEmptyDistanceImage()
   * The image's volume = 500000 Pixels = extentX*spacing*extentY*spacing*extentZ*spacing
   * So the spacing is: spacing = ( extentX*extentY*extentZ / 500000 )^(1/3)
   */
-  double basis = (extentMM[0]*extentMM[1]*extentMM[2]) / m_DistanceImageVolume;
-  double exponent = 1.0/3.0;
+  double basis = (extentMM[0] * extentMM[1] * extentMM[2]) / m_DistanceImageVolume;
+  double exponent = 1.0 / 3.0;
   m_DistanceImageSpacing = pow(basis, exponent);
 
   // calculate the number of pixels of the distance image for each direction
@@ -86,28 +83,29 @@ void mitk::CreateDistanceImageFromSurfaceFilter::CreateEmptyDistanceImage()
   //  * the largest possible region to set the extent to be calculated
   //  * the isotropic spacing that we have calculated above
   m_DistanceImageITK = DistanceImageType::New();
-  m_DistanceImageITK->SetOrigin( originAsWorld );
-  m_DistanceImageITK->SetDirection( m_ReferenceImage->GetDirection() );
-  m_DistanceImageITK->SetRegions( lpRegion );
-  m_DistanceImageITK->SetSpacing( m_DistanceImageSpacing );
+  m_DistanceImageITK->SetOrigin(originAsWorld);
+  m_DistanceImageITK->SetDirection(m_ReferenceImage->GetDirection());
+  m_DistanceImageITK->SetRegions(lpRegion);
+  m_DistanceImageITK->SetSpacing(m_DistanceImageSpacing);
   m_DistanceImageITK->Allocate();
 
-  //First of all the image is initialized with the value 10*m_DistanceImageSpacing for each pixel
-  m_DistanceImageDefaultBufferValue = 10*m_DistanceImageSpacing;
+  // First of all the image is initialized with the value 10*m_DistanceImageSpacing for each pixel
+  m_DistanceImageDefaultBufferValue = 10 * m_DistanceImageSpacing;
   m_DistanceImageITK->FillBuffer(m_DistanceImageDefaultBufferValue);
 
   // Now we move the origin of the distanceImage 2 index-Coordinates
   // in all directions
   DistanceImageType::IndexType originAsIndex;
-  m_DistanceImageITK->TransformPhysicalPointToIndex( originAsWorld, originAsIndex );
+  m_DistanceImageITK->TransformPhysicalPointToIndex(originAsWorld, originAsIndex);
   originAsIndex[0] -= 2;
   originAsIndex[1] -= 2;
   originAsIndex[2] -= 2;
-  m_DistanceImageITK->TransformIndexToPhysicalPoint( originAsIndex, originAsWorld );
-  m_DistanceImageITK->SetOrigin( originAsWorld );
+  m_DistanceImageITK->TransformIndexToPhysicalPoint(originAsIndex, originAsWorld);
+  m_DistanceImageITK->SetOrigin(originAsWorld);
 }
 
 mitk::CreateDistanceImageFromSurfaceFilter::CreateDistanceImageFromSurfaceFilter()
+  : m_DistanceImageSpacing(0.0), m_DistanceImageDefaultBufferValue(0.0)
 {
   m_DistanceImageVolume = 50000;
   this->m_UseProgressBar = false;
@@ -117,7 +115,6 @@ mitk::CreateDistanceImageFromSurfaceFilter::CreateDistanceImageFromSurfaceFilter
   this->SetNthOutput(0, output.GetPointer());
 }
 
-
 mitk::CreateDistanceImageFromSurfaceFilter::~CreateDistanceImageFromSurfaceFilter()
 {
 }
@@ -127,7 +124,7 @@ void mitk::CreateDistanceImageFromSurfaceFilter::GenerateData()
   this->PreprocessContourPoints();
   this->CreateEmptyDistanceImage();
 
-  //First of all we have to build the equation-system from the existing contour-edge-points
+  // First of all we have to build the equation-system from the existing contour-edge-points
   this->CreateSolutionMatrixAndFunctionValues();
 
   if (this->m_UseProgressBar)
@@ -138,7 +135,7 @@ void mitk::CreateDistanceImageFromSurfaceFilter::GenerateData()
   if (this->m_UseProgressBar)
     mitk::ProgressBar::GetInstance()->Progress(2);
 
-  //The last step is to create the distance map with the interpolated distance function
+  // The last step is to create the distance map with the interpolated distance function
   this->FillDistanceImage();
 
   if (this->m_UseProgressBar)
@@ -159,10 +156,9 @@ void mitk::CreateDistanceImageFromSurfaceFilter::PreprocessContourPoints()
     return;
   }
 
-  //First of all we have to extract the nomals and the surface points.
-  //Duplicated points can be eliminated
+  // First of all we have to extract the nomals and the surface points.
+  // Duplicated points can be eliminated
 
-  Surface* currentSurface;
   vtkSmartPointer<vtkPolyData> polyData;
   vtkSmartPointer<vtkDoubleArray> currentCellNormals;
   vtkSmartPointer<vtkCellArray> existingPolys;
@@ -174,12 +170,14 @@ void mitk::CreateDistanceImageFromSurfaceFilter::PreprocessContourPoints()
 
   for (unsigned int i = 0; i < numberOfInputs; i++)
   {
-    currentSurface = const_cast<Surface*>( this->GetInput(i) );
+    auto currentSurface = this->GetInput(i);
     polyData = currentSurface->GetVtkPolyData();
 
     if (polyData->GetNumberOfPolys() == 0)
     {
-      MITK_INFO << "mitk::CreateDistanceImageFromSurfaceFilter: No input-polygons available. Please be sure the input surface consists of polygons!" << std::endl;
+      MITK_INFO << "mitk::CreateDistanceImageFromSurfaceFilter: No input-polygons available. Please be sure the input "
+                   "surface consists of polygons!"
+                << std::endl;
     }
 
     currentCellNormals = vtkDoubleArray::SafeDownCast(polyData->GetCellData()->GetNormals());
@@ -190,18 +188,18 @@ void mitk::CreateDistanceImageFromSurfaceFilter::PreprocessContourPoints()
 
     existingPolys->InitTraversal();
 
-    vtkIdType* cell (nullptr);
-    vtkIdType cellSize (0);
+    const vtkIdType *cell(nullptr);
+    vtkIdType cellSize(0);
 
-    for( existingPolys->InitTraversal(); existingPolys->GetNextCell(cellSize, cell);)
+    for (existingPolys->InitTraversal(); existingPolys->GetNextCell(cellSize, cell);)
     {
-      for ( vtkIdType j = 0; j < cellSize; j++ )
+      for (vtkIdType j = 0; j < cellSize; j++)
       {
         existingPoints->GetPoint(cell[j], p);
 
         currentPoint.copy_in(p);
 
-        int count = std::count(m_Centers.begin() ,m_Centers.end(),currentPoint);
+        int count = std::count(m_Centers.begin(), m_Centers.end(), currentPoint);
 
         if (count == 0)
         {
@@ -215,55 +213,55 @@ void mitk::CreateDistanceImageFromSurfaceFilter::PreprocessContourPoints()
           m_Centers.push_back(currentPoint);
         }
 
-      }//end for all points
-    }//end for all cells
-  }//end for all outputs
+      } // end for all points
+    }   // end for all cells
+  }     // end for all outputs
 }
 
 void mitk::CreateDistanceImageFromSurfaceFilter::CreateSolutionMatrixAndFunctionValues()
 {
-  //For we can now calculate the exact size of the centers we initialize the data structures
+  // For we can now calculate the exact size of the centers we initialize the data structures
   unsigned int numberOfCenters = m_Centers.size();
-  m_Centers.reserve(numberOfCenters*3);
+  m_Centers.reserve(numberOfCenters * 3);
 
-  m_FunctionValues.resize(numberOfCenters*3);
+  m_FunctionValues.resize(numberOfCenters * 3);
 
   m_FunctionValues.fill(0);
 
   PointType currentPoint;
   PointType normal;
 
-  //Create inner points
+  // Create inner points
   for (unsigned int i = 0; i < numberOfCenters; i++)
   {
     currentPoint = m_Centers.at(i);
     normal = m_Normals.at(i);
 
-    currentPoint[0] = currentPoint[0] - normal[0]*m_DistanceImageSpacing;
-    currentPoint[1] = currentPoint[1] - normal[1]*m_DistanceImageSpacing;
-    currentPoint[2] = currentPoint[2] - normal[2]*m_DistanceImageSpacing;
+    currentPoint[0] = currentPoint[0] - normal[0] * m_DistanceImageSpacing;
+    currentPoint[1] = currentPoint[1] - normal[1] * m_DistanceImageSpacing;
+    currentPoint[2] = currentPoint[2] - normal[2] * m_DistanceImageSpacing;
 
     m_Centers.push_back(currentPoint);
 
-    m_FunctionValues[numberOfCenters+i] = -m_DistanceImageSpacing;
+    m_FunctionValues[numberOfCenters + i] = -m_DistanceImageSpacing;
   }
 
-  //Create outer points
+  // Create outer points
   for (unsigned int i = 0; i < numberOfCenters; i++)
   {
     currentPoint = m_Centers.at(i);
     normal = m_Normals.at(i);
 
-    currentPoint[0] = currentPoint[0] + normal[0]*m_DistanceImageSpacing;
-    currentPoint[1] = currentPoint[1] + normal[1]*m_DistanceImageSpacing;
-    currentPoint[2] = currentPoint[2] + normal[2]*m_DistanceImageSpacing;
+    currentPoint[0] = currentPoint[0] + normal[0] * m_DistanceImageSpacing;
+    currentPoint[1] = currentPoint[1] + normal[1] * m_DistanceImageSpacing;
+    currentPoint[2] = currentPoint[2] + normal[2] * m_DistanceImageSpacing;
 
     m_Centers.push_back(currentPoint);
 
-    m_FunctionValues[numberOfCenters*2+i] = m_DistanceImageSpacing;
+    m_FunctionValues[numberOfCenters * 2 + i] = m_DistanceImageSpacing;
   }
 
-  //Now we have created all centers and all function values. Next step is to create the solution matrix
+  // Now we have created all centers and all function values. Next step is to create the solution matrix
   numberOfCenters = m_Centers.size();
 
   m_SolutionMatrix.resize(numberOfCenters, numberOfCenters);
@@ -278,12 +276,12 @@ void mitk::CreateDistanceImageFromSurfaceFilter::CreateSolutionMatrixAndFunction
   {
     for (unsigned int j = 0; j < numberOfCenters; j++)
     {
-      //Calculate the RBF value. Currently using Phi(r) = r with r is the euclidian distance between two points
+      // Calculate the RBF value. Currently using Phi(r) = r with r is the euclidian distance between two points
       p1 = m_Centers.at(i);
       p2 = m_Centers.at(j);
       p1 = p1 - p2;
       norm = p1.two_norm();
-      m_SolutionMatrix(i,j) = norm;
+      m_SolutionMatrix(i, j) = norm;
     }
   }
 }
@@ -316,9 +314,10 @@ void mitk::CreateDistanceImageFromSurfaceFilter::FillDistanceImage()
 
   // Transform the input point in world-coordinates to index-coordinates
   DistanceImageType::IndexType currentIndex;
-  m_DistanceImageITK->TransformPhysicalPointToIndex( currentPointAsPoint, currentIndex );
+  m_DistanceImageITK->TransformPhysicalPointToIndex(currentPointAsPoint, currentIndex);
 
-  assert( m_DistanceImageITK->GetLargestPossibleRegion().IsInside(currentIndex) ); // we are quite certain this should hold
+  assert(
+    m_DistanceImageITK->GetLargestPossibleRegion().IsInside(currentIndex)); // we are quite certain this should hold
 
   narrowbandPoints.push(currentIndex);
   m_DistanceImageITK->SetPixel(currentIndex, distance);
@@ -329,23 +328,22 @@ void mitk::CreateDistanceImageFromSurfaceFilter::FillDistanceImage()
   unsigned int relativeNbIdx[] = {4, 10, 12, 14, 16, 22};
 
   bool isInBounds = false;
-  while ( !narrowbandPoints.empty() )
+  while (!narrowbandPoints.empty())
   {
-
     nIt.SetLocation(narrowbandPoints.front());
     narrowbandPoints.pop();
 
-    unsigned int* relativeNb = &relativeNbIdx[0];
+    unsigned int *relativeNb = &relativeNbIdx[0];
     for (int i = 0; i < 6; i++)
     {
       nIt.GetPixel(*relativeNb, isInBounds);
-      if( isInBounds && nIt.GetPixel(*relativeNb) == m_DistanceImageDefaultBufferValue)
+      if (isInBounds && nIt.GetPixel(*relativeNb) == m_DistanceImageDefaultBufferValue)
       {
         currentIndex = nIt.GetIndex(*relativeNb);
 
         // Transform the currently checked point from index-coordinates to
         // world-coordinates
-        m_DistanceImageITK->TransformIndexToPhysicalPoint( currentIndex, currentPointAsPoint );
+        m_DistanceImageITK->TransformIndexToPhysicalPoint(currentIndex, currentPointAsPoint);
 
         // create a vnl_vector
         currentPoint[0] = currentPointAsPoint[0];
@@ -354,7 +352,7 @@ void mitk::CreateDistanceImageFromSurfaceFilter::FillDistanceImage()
 
         // and check the distance
         distance = this->CalculateDistanceValue(currentPoint);
-        if ( std::fabs(distance) <= m_DistanceImageSpacing*2 )
+        if (std::fabs(distance) <= m_DistanceImageSpacing * 2)
         {
           nIt.SetPixel(*relativeNb, distance);
           narrowbandPoints.push(currentIndex);
@@ -364,8 +362,7 @@ void mitk::CreateDistanceImageFromSurfaceFilter::FillDistanceImage()
     }
   }
 
-
-  ImageIterator imgRegionIterator (m_DistanceImageITK, m_DistanceImageITK->GetLargestPossibleRegion());
+  ImageIterator imgRegionIterator(m_DistanceImageITK, m_DistanceImageITK->GetLargestPossibleRegion());
   imgRegionIterator.GoToBegin();
 
   double prevPixelVal = 1;
@@ -374,16 +371,17 @@ void mitk::CreateDistanceImageFromSurfaceFilter::FillDistanceImage()
   _size.Fill(-1);
   _size += m_DistanceImageITK->GetLargestPossibleRegion().GetSize();
 
-  //Set every pixel inside the surface to -m_DistanceImageDefaultBufferValue except the edge point (so that the received surface is closed)
-  while (!imgRegionIterator.IsAtEnd()) {
-
-    if ( imgRegionIterator.Get() == m_DistanceImageDefaultBufferValue && prevPixelVal < 0 )
+  // Set every pixel inside the surface to -m_DistanceImageDefaultBufferValue except the edge point (so that the
+  // received surface is closed)
+  while (!imgRegionIterator.IsAtEnd())
+  {
+    if (imgRegionIterator.Get() == m_DistanceImageDefaultBufferValue && prevPixelVal < 0)
     {
-
       while (imgRegionIterator.Get() == m_DistanceImageDefaultBufferValue)
       {
-        if (imgRegionIterator.GetIndex()[0] == _size[0] || imgRegionIterator.GetIndex()[1] == _size[1] || imgRegionIterator.GetIndex()[2] == _size[2]
-            || imgRegionIterator.GetIndex()[0] == 0U || imgRegionIterator.GetIndex()[1] == 0U || imgRegionIterator.GetIndex()[2] == 0U )
+        if (imgRegionIterator.GetIndex()[0] == _size[0] || imgRegionIterator.GetIndex()[1] == _size[1] ||
+            imgRegionIterator.GetIndex()[2] == _size[2] || imgRegionIterator.GetIndex()[0] == 0U ||
+            imgRegionIterator.GetIndex()[1] == 0U || imgRegionIterator.GetIndex()[2] == 0U)
         {
           imgRegionIterator.Set(m_DistanceImageDefaultBufferValue);
           prevPixelVal = m_DistanceImageDefaultBufferValue;
@@ -392,16 +390,15 @@ void mitk::CreateDistanceImageFromSurfaceFilter::FillDistanceImage()
         }
         else
         {
-          imgRegionIterator.Set((-1)*m_DistanceImageDefaultBufferValue);
+          imgRegionIterator.Set((-1) * m_DistanceImageDefaultBufferValue);
           ++imgRegionIterator;
-          prevPixelVal = (-1)*m_DistanceImageDefaultBufferValue;
+          prevPixelVal = (-1) * m_DistanceImageDefaultBufferValue;
         }
-
       }
-
     }
-    else if (imgRegionIterator.GetIndex()[0] == _size[0] || imgRegionIterator.GetIndex()[1] == _size[1] || imgRegionIterator.GetIndex()[2] == _size[2]
-             || imgRegionIterator.GetIndex()[0] == 0U || imgRegionIterator.GetIndex()[1] == 0U || imgRegionIterator.GetIndex()[2] == 0U)
+    else if (imgRegionIterator.GetIndex()[0] == _size[0] || imgRegionIterator.GetIndex()[1] == _size[1] ||
+             imgRegionIterator.GetIndex()[2] == _size[2] || imgRegionIterator.GetIndex()[0] == 0U ||
+             imgRegionIterator.GetIndex()[1] == 0U || imgRegionIterator.GetIndex()[2] == 0U)
 
     {
       imgRegionIterator.Set(m_DistanceImageDefaultBufferValue);
@@ -424,20 +421,18 @@ void mitk::CreateDistanceImageFromSurfaceFilter::FillDistanceImage()
 
 double mitk::CreateDistanceImageFromSurfaceFilter::CalculateDistanceValue(PointType p)
 {
-  double distanceValue (0);
+  double distanceValue(0);
   PointType p1;
   PointType p2;
   double norm;
 
   CenterList::iterator centerIter;
 
-  unsigned int count (0);
-  for ( centerIter=m_Centers.begin();
-    centerIter!=m_Centers.end();
-    centerIter++)
+  unsigned int count(0);
+  for (centerIter = m_Centers.begin(); centerIter != m_Centers.end(); centerIter++)
   {
     p1 = *centerIter;
-    p2 = p-p1;
+    p2 = p - p1;
     norm = p2.two_norm();
     distanceValue = distanceValue + (norm * m_Weights[count]);
     ++count;
@@ -452,67 +447,63 @@ void mitk::CreateDistanceImageFromSurfaceFilter::GenerateOutputInformation()
 void mitk::CreateDistanceImageFromSurfaceFilter::PrintEquationSystem()
 {
   std::stringstream out;
-  out<<"Nummber of rows: "<<m_SolutionMatrix.rows()<<" ****** Number of columns: "<<m_SolutionMatrix.cols()<<endl;
-  out<<"[ ";
+  out << "Nummber of rows: " << m_SolutionMatrix.rows() << " ****** Number of columns: " << m_SolutionMatrix.cols()
+      << endl;
+  out << "[ ";
   for (int i = 0; i < m_SolutionMatrix.rows(); i++)
   {
     for (int j = 0; j < m_SolutionMatrix.cols(); j++)
     {
-      out<<m_SolutionMatrix(i,j)<<"   ";
+      out << m_SolutionMatrix(i, j) << "   ";
     }
-    out<<";"<<endl;
+    out << ";" << endl;
   }
-  out<<" ]\n\n\n";
+  out << " ]\n\n\n";
 
   for (unsigned int i = 0; i < m_Centers.size(); i++)
   {
-    out<<m_Centers.at(i)<<";"<<endl;
+    out << m_Centers.at(i) << ";" << endl;
   }
-  std::cout<<"Equation system: \n\n\n"<<out.str();
+  std::cout << "Equation system: \n\n\n" << out.str();
 }
 
-
-
-void mitk::CreateDistanceImageFromSurfaceFilter::SetInput( const mitk::Surface* surface )
+void mitk::CreateDistanceImageFromSurfaceFilter::SetInput(const mitk::Surface *surface)
 {
-    this->SetInput( 0, const_cast<mitk::Surface*>( surface ) );
+  this->SetInput(0, surface);
 }
 
-
-void mitk::CreateDistanceImageFromSurfaceFilter::SetInput( unsigned int idx, const mitk::Surface* surface )
+void mitk::CreateDistanceImageFromSurfaceFilter::SetInput(unsigned int idx, const mitk::Surface *surface)
 {
-    if ( this->GetInput(idx) != surface )
-    {
-        this->SetNthInput( idx, const_cast<mitk::Surface*>( surface ) );
-        this->Modified();
-    }
+  if (this->GetInput(idx) != surface)
+  {
+    this->SetNthInput(idx, const_cast<mitk::Surface *>(surface));
+    this->Modified();
+  }
 }
 
-
-const mitk::Surface* mitk::CreateDistanceImageFromSurfaceFilter::GetInput()
+const mitk::Surface *mitk::CreateDistanceImageFromSurfaceFilter::GetInput()
 {
-    if (this->GetNumberOfIndexedInputs() < 1)
-        return nullptr;
+  if (this->GetNumberOfIndexedInputs() < 1)
+    return nullptr;
 
-    return static_cast<const mitk::Surface*>(this->ProcessObject::GetInput(0));
+  return static_cast<const mitk::Surface *>(this->ProcessObject::GetInput(0));
 }
 
-
-const mitk::Surface* mitk::CreateDistanceImageFromSurfaceFilter::GetInput( unsigned int idx)
+const mitk::Surface *mitk::CreateDistanceImageFromSurfaceFilter::GetInput(unsigned int idx)
 {
-    if (this->GetNumberOfIndexedInputs() < 1)
-        return nullptr;
+  if (this->GetNumberOfIndexedInputs() < 1)
+    return nullptr;
 
-    return static_cast<const mitk::Surface*>(this->ProcessObject::GetInput(idx));
+  return static_cast<const mitk::Surface *>(this->ProcessObject::GetInput(idx));
 }
 
-void mitk::CreateDistanceImageFromSurfaceFilter::RemoveInputs(mitk::Surface* input)
+void mitk::CreateDistanceImageFromSurfaceFilter::RemoveInputs(mitk::Surface *input)
 {
   DataObjectPointerArraySizeType nb = this->GetNumberOfIndexedInputs();
 
-  for(DataObjectPointerArraySizeType i = 0; i < nb; i++)
+  for (DataObjectPointerArraySizeType i = 0; i < nb; i++)
   {
-    if( this->GetInput(i) == input )
+    if (this->GetInput(i) == input)
     {
       this->RemoveInput(i);
       return;
@@ -543,15 +534,16 @@ void mitk::CreateDistanceImageFromSurfaceFilter::SetProgressStepSize(unsigned in
   this->m_ProgressStepSize = stepSize;
 }
 
-void mitk::CreateDistanceImageFromSurfaceFilter::SetReferenceImage( itk::ImageBase<3>::Pointer referenceImage )
+void mitk::CreateDistanceImageFromSurfaceFilter::SetReferenceImage(itk::ImageBase<3>::Pointer referenceImage)
 {
- m_ReferenceImage = referenceImage;
+  m_ReferenceImage = referenceImage;
 }
 
-void mitk::CreateDistanceImageFromSurfaceFilter::DetermineBounds( DistanceImageType::PointType &minPointInWorldCoordinates,
-                                                                  DistanceImageType::PointType &maxPointInWorldCoordinates,
-                                                                  DistanceImageType::IndexType &minPointInIndexCoordinates,
-                                                                  DistanceImageType::IndexType &maxPointInIndexCoordinates )
+void mitk::CreateDistanceImageFromSurfaceFilter::DetermineBounds(
+  DistanceImageType::PointType &minPointInWorldCoordinates,
+  DistanceImageType::PointType &maxPointInWorldCoordinates,
+  DistanceImageType::IndexType &minPointInIndexCoordinates,
+  DistanceImageType::IndexType &maxPointInIndexCoordinates)
 {
   PointType firstCenter = m_Centers.at(0);
   DistanceImageType::PointType tmpPoint;
@@ -561,7 +553,7 @@ void mitk::CreateDistanceImageFromSurfaceFilter::DetermineBounds( DistanceImageT
 
   // transform the first point from world-coordinates to index-coordinates
   itk::ContinuousIndex<double, 3> tmpIndex;
-  m_ReferenceImage->TransformPhysicalPointToContinuousIndex( tmpPoint, tmpIndex );
+  m_ReferenceImage->TransformPhysicalPointToContinuousIndex(tmpPoint, tmpIndex);
 
   // initialize the variables with this first point
   DistanceImageType::IndexValueType xmin = tmpIndex[0];
@@ -573,15 +565,14 @@ void mitk::CreateDistanceImageFromSurfaceFilter::DetermineBounds( DistanceImageT
 
   // iterate over the rest of the points
   auto centerIter = m_Centers.begin();
-  for ( ++centerIter; centerIter!=m_Centers.end(); centerIter++)
+  for (++centerIter; centerIter != m_Centers.end(); centerIter++)
   {
     tmpPoint[0] = (*centerIter)[0];
     tmpPoint[1] = (*centerIter)[1];
     tmpPoint[2] = (*centerIter)[2];
 
-
     // transform each point from world-coordinates to index-coordinates
-    m_ReferenceImage->TransformPhysicalPointToContinuousIndex( tmpPoint, tmpIndex );
+    m_ReferenceImage->TransformPhysicalPointToContinuousIndex(tmpPoint, tmpIndex);
 
     // and set the variables accordingly to find the minimum
     // and maximum in all directions in index-coordinates
@@ -621,7 +612,6 @@ void mitk::CreateDistanceImageFromSurfaceFilter::DetermineBounds( DistanceImageT
   maxPointInIndexCoordinates[2] = zmax;
 
   // and transform them into world-coordinates
-  m_ReferenceImage->TransformIndexToPhysicalPoint( minPointInIndexCoordinates, minPointInWorldCoordinates );
-  m_ReferenceImage->TransformIndexToPhysicalPoint( maxPointInIndexCoordinates, maxPointInWorldCoordinates );
+  m_ReferenceImage->TransformIndexToPhysicalPoint(minPointInIndexCoordinates, minPointInWorldCoordinates);
+  m_ReferenceImage->TransformIndexToPhysicalPoint(maxPointInIndexCoordinates, maxPointInWorldCoordinates);
 }
-
