@@ -1,20 +1,16 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
-#ifndef __mitkToFCameraPMDO3Device_h
-#define __mitkToFCameraPMDO3Device_h
+============================================================================*/
+#ifndef mitkToFCameraPMDO3Device_h
+#define mitkToFCameraPMDO3Device_h
 
 #include <MitkPMDExports.h>
 #include "mitkCommon.h"
@@ -41,8 +37,9 @@ namespace mitk
 
     mitkClassMacro( ToFCameraPMDO3Device , ToFCameraPMDDevice );
 
-    itkFactorylessNewMacro(Self)
-    itkCloneMacro(Self)
+    itkFactorylessNewMacro(Self);
+
+    itkCloneMacro(Self);
 
   protected:
 
