@@ -1,20 +1,16 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
-#ifndef __mitkToFCameraPMDRawDataCamCubeDevice_h
-#define __mitkToFCameraPMDRawDataCamCubeDevice_h
+============================================================================*/
+#ifndef mitkToFCameraPMDRawDataCamCubeDevice_h
+#define mitkToFCameraPMDRawDataCamCubeDevice_h
 
 #include <MitkPMDExports.h>
 #include "mitkCommon.h"
@@ -35,8 +31,9 @@ namespace mitk
 
     mitkClassMacro( ToFCameraPMDRawDataCamCubeDevice , ToFCameraPMDRawDataDevice );
 
-    itkFactorylessNewMacro(Self)
-    itkCloneMacro(Self)
+    itkFactorylessNewMacro(Self);
+
+    itkCloneMacro(Self);
 
     virtual void SetProperty( const char *propertyKey, BaseProperty* propertyValue );
 
