@@ -1,21 +1,17 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-#ifndef __mitkUSTelemedActivator_h
-#define __mitkUSTelemedActivator_h
+#ifndef mitkUSTelemedActivator_h
+#define mitkUSTelemedActivator_h
 
 #include "mitkUSTelemedDevice.h"
 
@@ -50,4 +46,4 @@ namespace mitk
 
 US_EXPORT_MODULE_ACTIVATOR(mitk::USTelemedActivator)
 
-#endif // __mitkUSTelemedActivator_h
\ No newline at end of file
+#endif
