@@ -1,21 +1,17 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-#ifndef MITKUSTelemedDopplerControls_H_HEADER_INCLUDED_
-#define MITKUSTelemedDopplerControls_H_HEADER_INCLUDED_
+#ifndef mitkUSTelemedDopplerControls_h
+#define mitkUSTelemedDopplerControls_h
 
 #include "mitkUSTelemedSDKHeader.h"
 #include "mitkUSControlInterfaceDoppler.h"
@@ -47,4 +43,4 @@ namespace mitk {
   };
 }
 
-#endif // MITKUSTelemedDopplerControls_H_HEADER_INCLUDED_
\ No newline at end of file
+#endif
