@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRY_Platform_INCLUDED
 #define BERRY_Platform_INCLUDED
@@ -172,13 +168,17 @@ class Path;
 
 }
 
+namespace mitk
+{
+  class IPreferencesService;
+}
+
 namespace berry {
 
 struct IAdapterManager;
 struct IBundle;
 struct IExtensionPointService;
 struct IExtensionRegistry;
-struct IPreferencesService;
 struct IProduct;
 
 
@@ -243,9 +243,6 @@ public:
   static const QString PROP_APPLICATION;
   static const QString PROP_IGNOREAPP;
 
-  static const QString PROP_TESTPLUGIN;
-  static const QString PROP_TESTAPPLICATION;
-
   static const QString PROP_XARGS;
 
   /**
@@ -269,15 +266,11 @@ public:
   /**
    * Return the interface into the preference mechanism. The returned
    * object can be used for such operations as searching for preference
-   * values across multiple scopes and preference import/export.
-   * <p>
-   * Clients are also able to acquire the IPreferencesService service via
-   * CTK mechanisms and use it for preference functions.
-   * </p>
+   * values across multiple scopes.
    *
    * @return an object to interface into the preference mechanism
    */
-  static IPreferencesService* GetPreferencesService();
+  static mitk::IPreferencesService* GetPreferencesService();
 
   /**
    * Returns the product which was selected when running this BlueBerry instance
@@ -292,7 +285,7 @@ public:
    * in the general form <i>&lt;plug-in id&gt;/&lt;option-path&gt;</i>.
    * For example, <code>org.blueberry.core.runtime/debug</code>
    * <p>
-   * Clients are also able to acquire the {@link DebugOptions} service
+   * Clients are also able to acquire the \c DebugOptions service
    * and query it for debug options.
    * </p>
    * @param option the name of the option to lookup
@@ -385,7 +378,9 @@ public:
    * other configuration parameters.
    * </p>
    *
+   * @param statePath
    * @param plugin the plug-in whose state location is returned
+   * @param create
    * @return a local file system path
    * TODO Investigate the usage of a service factory
    * @deprecatedSince{2015_05} Use GetStateLocation instead.
