@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYIPAGELAYOUT_H_
 #define BERRYIPAGELAYOUT_H_
@@ -37,7 +33,7 @@ namespace berry {
  * <p>
  * When a perspective is opened, it creates a new page layout with a single editor area.
  * This layout is then passed to the perspective factory (implementation of
- * {@link org.blueberry.ui.IPerspectiveFactory#createInitialLayout(IPageLayout)}) where
+ * {@link IPerspectiveFactory#CreateInitialLayout}) where
  * additional views and other content can be added, using the existing editor area as
  * the initial point of reference.
  * </p>
@@ -82,12 +78,12 @@ namespace berry {
  * layout.addView(IPageLayout.ID_TASK_LIST, IPageLayout.BOTTOM, 0.66f, editorArea);
  * </pre>
  * </p>
- * @noimplement This interface is not intended to be implemented by clients.
+ * @note This interface is not intended to be implemented by clients.
  */
 struct BERRY_UI_QT IPageLayout : public Object
 {
 
-  berryObjectMacro(berry::IPageLayout)
+  berryObjectMacro(berry::IPageLayout);
 
     /**
      * The part id for the workbench's editor area.  This may only be used
@@ -191,17 +187,7 @@ struct BERRY_UI_QT IPageLayout : public Object
      * A variable used to represent a ratio which has not been specified.
      * @since 2.0
      */
-    static const float NULL_RATIO; // = -2f;
-
-    /**
-     * Adds an action set with the given id to this page layout.
-     * The id must name an action set contributed to the workbench's extension
-     * point (named <code>"org.blueberry.ui.actionSet"</code>).
-     *
-     * @param actionSetId the action set id
-     */
-    //virtual void AddActionSet(const QString& actionSetId) = 0;
-
+    static const float nullptr_RATIO; // = -2f;
 
     /**
      * Adds a perspective shortcut to the page layout.
