@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYIREUSABLEEDITOR_H_
 #define BERRYIREUSABLEEDITOR_H_
@@ -34,14 +30,14 @@ namespace berry {
 struct BERRY_UI_QT IReusableEditor : public virtual IEditorPart
 {
 
-  berryObjectMacro(berry::IReusableEditor)
+  berryObjectMacro(berry::IReusableEditor);
 
-  virtual ~IReusableEditor();
+  ~IReusableEditor() override;
 
     /**
      * Sets the input to this editor.
      *
-     * <p><b>Note:</b> Clients must fire the {@link IEditorPart#PROP_INPUT }
+     * <p><b>Note:</b> Clients must fire the {@link IWorkbenchPartConstants#PROP_INPUT }
      * property change within their implementation of
      * <code>setInput()</code>.<p>
      *
