@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYIVIEWCATEGORY_H_
 #define BERRYIVIEWCATEGORY_H_
@@ -30,14 +26,14 @@ namespace berry {
  */
 struct BERRY_UI_QT IViewCategory : public virtual Object
 {
-  berryObjectMacro(berry::IViewCategory)
+  berryObjectMacro(berry::IViewCategory);
 
   virtual QString GetId() const = 0;
   virtual QString GetLabel() const = 0;
   virtual QStringList GetPath() const = 0;
   virtual QList<IViewDescriptor::Pointer> GetViews() const = 0;
 
-  virtual ~IViewCategory();
+  ~IViewCategory() override;
 };
 
 }
