@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYIVIEWREFERENCE_H_
 #define BERRYIVIEWREFERENCE_H_
@@ -32,9 +28,9 @@ namespace berry {
  */
 struct BERRY_UI_QT IViewReference : virtual public IWorkbenchPartReference {
 
-  berryObjectMacro(berry::IViewReference)
+  berryObjectMacro(berry::IViewReference);
 
-  ~IViewReference();
+  ~IViewReference() override;
 
     /**
      * Returns the secondary ID for the view.
