@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYIVIEWSITE_H_
 #define BERRYIVIEWSITE_H_
@@ -31,14 +27,13 @@ namespace berry {
  * The workbench exposes its implemention of view part sites via this interface,
  * which is not intended to be implemented or extended by clients.
  * </p>
- * @noimplement This interface is not intended to be implemented by clients.
  */
 struct BERRY_UI_QT IViewSite : public virtual IWorkbenchPartSite
 {
 
-  berryObjectMacro(berry::IViewSite)
+  berryObjectMacro(berry::IViewSite);
 
-  virtual ~IViewSite();
+  ~IViewSite() override;
 
     /**
      * Returns the action bars for this part site.
