@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYEDITORREGISTRY_H_
 #define BERRYEDITORREGISTRY_H_
@@ -123,9 +119,7 @@ private: EditorRegistry* editorRegistry;
    public: QList<FileEditorMapping::Pointer> UserMappings();
    };
 
- struct CmpFileEditorMapping : public std::binary_function<FileEditorMapping::Pointer,
-                                                     FileEditorMapping::Pointer,
-                                                     bool>
+ struct CmpFileEditorMapping
  {
    bool operator()(const FileEditorMapping::Pointer& x, const FileEditorMapping::Pointer& y) const
    {
@@ -133,9 +127,7 @@ private: EditorRegistry* editorRegistry;
    }
  };
 
- struct CmpIEditorDescriptor : public std::binary_function<IEditorDescriptor::Pointer,
-                                                      IEditorDescriptor::Pointer,
-                                                      bool>
+ struct CmpIEditorDescriptor
   {
     bool operator()(const IEditorDescriptor::Pointer& x, const IEditorDescriptor::Pointer& y) const
     {
@@ -143,9 +135,7 @@ private: EditorRegistry* editorRegistry;
     }
   };
 
- struct CmpEditorDescriptor : public std::binary_function<EditorDescriptor::Pointer,
-                                                       EditorDescriptor::Pointer,
-                                                       bool>
+ struct CmpEditorDescriptor
    {
      bool operator()(const EditorDescriptor::Pointer& x, const EditorDescriptor::Pointer& y) const
      {
