@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYPARTPLACEHOLDER_H_
 #define BERRYPARTPLACEHOLDER_H_
@@ -30,7 +26,7 @@ class PartPlaceholder : public LayoutPart {
 
 public:
 
-  berryObjectMacro(PartPlaceholder)
+  berryObjectMacro(PartPlaceholder);
 
     /**
      * Placeholder ids may contain wildcards.  This is the wildcard string.
