@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "tweaklets/berryGuiWidgetsTweaklet.h"
 
@@ -869,7 +865,6 @@ bool Perspective::RestoreState()
 //      PlatformUI.PLUGIN_ID,
 //      IStatus.OK,
 //      WorkbenchMessages.Perspective_problemsRestoringPerspective, 0);
-  bool result = true;
 
   IMemento::Pointer memento = this->memento;
   this->memento = nullptr;
@@ -912,8 +907,7 @@ bool Perspective::RestoreState()
   // Read the layout.
 //  result.merge(pres.restoreState(memento
 //          .getChild(IWorkbenchConstants.TAG_LAYOUT)));
-  result &= pres->RestoreState(memento->GetChild(WorkbenchConstants::TAG_LAYOUT));
-
+          pres->RestoreState(memento->GetChild(WorkbenchConstants::TAG_LAYOUT));
   //StartupThreading.runWithoutExceptions(new StartupRunnable()
   //    {
 
