@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYPERSPECTIVE_H_
 #define BERRYPERSPECTIVE_H_
@@ -45,7 +41,7 @@ class Perspective : public Object {
 
 public:
 
-  berryObjectMacro(Perspective)
+  berryObjectMacro(Perspective);
 
   friend class WorkbenchPage;
 
@@ -151,7 +147,7 @@ public: Perspective(PerspectiveDescriptor::Pointer desc, WorkbenchPage::Pointer
     /**
      * Dispose the perspective and all views contained within.
      */
-    public: ~Perspective();
+    public: ~Perspective() override;
 
     private: void DisposeViewRefs();
 
