@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
 #ifndef BERRYQTCONTROLWIDGET_H_
@@ -31,9 +27,9 @@ class BERRY_UI_QT QtControlWidget : public QFrame
 
 public:
 
-  QtControlWidget(QWidget* parent, Shell* shell, Qt::WindowFlags f = 0);
+  QtControlWidget(QWidget* parent, Shell* shell, Qt::WindowFlags f = nullptr);
 
-  ~QtControlWidget();
+  ~QtControlWidget() override;
 
   void FireActivateEvent();
 
