@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "berryWorkbenchSourceProvider.h"
 
@@ -64,10 +60,7 @@ WorkbenchSourceProvider::WorkbenchSourceProvider()
   , lastActivePart(nullptr)
   , lastActivePartSite(nullptr)
   , lastShowInInput(nullptr)
-  , lastEditorInput(nullptr)
   , display(nullptr)
-  , lastActiveShell(nullptr)
-  , lastActiveWorkbenchWindowShell(nullptr)
 {
 }
 
@@ -94,8 +87,8 @@ WorkbenchSourceProvider::~WorkbenchSourceProvider()
   qApp->removeEventFilter(this);
   HookListener(const_cast<WorkbenchWindow*>(lastActiveWorkbenchWindow.Lock().GetPointer()), nullptr);
   lastActiveWorkbenchWindow.Reset();
-  lastActiveWorkbenchWindowShell = nullptr;
-  lastActiveShell = nullptr;
+  lastActiveWorkbenchWindowShell.Reset();
+  lastActiveShell.Reset();
   lastWindow.Reset();
 }
 
@@ -124,7 +117,7 @@ void WorkbenchSourceProvider::SelectionChanged(const SmartPointer<IWorkbenchPart
 
   selection = newSelection;
 
-  LogDebuggingInfo(QString("Selection changed to ") + (selection ? selection->ToString() : QString("NULL")));
+  LogDebuggingInfo(QString("Selection changed to ") + (selection ? selection->ToString() : QString("nullptr")));
 
   FireSourceChanged(ISources::ACTIVE_CURRENT_SELECTION(),
                     ISources::ACTIVE_CURRENT_SELECTION_NAME(), selection);
@@ -224,9 +217,9 @@ void WorkbenchSourceProvider::WindowOpened(const SmartPointer<IWorkbenchWindow>&
 
 void WorkbenchSourceProvider::HandleCheck(const SmartPointer<const Shell>& s)
 {
-  if (s != lastActiveShell)
+  if (s != lastActiveShell.Lock())
   {
-    lastActiveShell = s.GetPointer();
+    lastActiveShell = s;
     CheckActivePart();
     IWorkbenchWindow* window = nullptr;
     if (s.IsNotNull())
@@ -316,18 +309,24 @@ void WorkbenchSourceProvider::CheckActivePart(bool updateShowInSelection)
     lastActiveEditor = newActiveEditor.Cast<const IEditorPart>().GetPointer();
   }
   const Object::ConstPointer newEditorInput = currentState.value(ISources::ACTIVE_EDITOR_INPUT_NAME());
-  if (newEditorInput != lastEditorInput)
+  IEditorInput::ConstPointer lastInput;
+  if (!lastEditorInput.Expired())
+  {
+    lastInput = lastEditorInput.Lock();
+  }
+  if (newEditorInput != lastInput)
   {
     sources |= ISources::ACTIVE_EDITOR();
     if (newEditorInput != IEvaluationContext::UNDEFINED_VARIABLE)
     {
-      lastEditorInput = newEditorInput.Cast<const IEditorInput>().GetPointer();
+      lastEditorInput = newEditorInput.Cast<const IEditorInput>();
     }
     else
     {
-      lastEditorInput = nullptr;
+      lastEditorInput.Reset();
     }
   }
+
   const Object::ConstPointer newActiveEditorId = currentState.value(ISources::ACTIVE_EDITOR_ID_NAME());
   if (newActiveEditorId != lastActiveEditorId)
   {
@@ -349,23 +348,23 @@ void WorkbenchSourceProvider::CheckActivePart(bool updateShowInSelection)
     {
       if ((sources & ISources::ACTIVE_PART()) != 0)
       {
-        LogDebuggingInfo("Active part changed to " + (lastActivePart ? lastActivePart->ToString() : QString("NULL")));
+        LogDebuggingInfo("Active part changed to " + (lastActivePart ? lastActivePart->ToString() : QString("nullptr")));
       }
       if ((sources & ISources::ACTIVE_PART_ID()) != 0)
       {
-        LogDebuggingInfo("Active part id changed to " + (lastActivePartId ? lastActivePartId->ToString() : QString("NULL")));
+        LogDebuggingInfo("Active part id changed to " + (lastActivePartId ? lastActivePartId->ToString() : QString("nullptr")));
       }
       if ((sources & ISources::ACTIVE_SITE()) != 0)
       {
-        LogDebuggingInfo("Active site changed to " + (lastActivePartSite ? lastActivePartSite->ToString() : QString("NULL")));
+        LogDebuggingInfo("Active site changed to " + (lastActivePartSite ? lastActivePartSite->ToString() : QString("nullptr")));
       }
       if ((sources & ISources::ACTIVE_EDITOR()) != 0)
       {
-        LogDebuggingInfo("Active editor changed to " + (lastActiveEditor ? lastActiveEditor->ToString() : QString("NULL")));
+        LogDebuggingInfo("Active editor changed to " + (lastActiveEditor ? lastActiveEditor->ToString() : QString("nullptr")));
       }
       if ((sources & ISources::ACTIVE_EDITOR_ID()) != 0)
       {
-        LogDebuggingInfo("Active editor id changed to " + (lastActiveEditorId ? lastActiveEditorId->ToString() : QString("NULL")));
+        LogDebuggingInfo("Active editor id changed to " + (lastActiveEditorId ? lastActiveEditorId->ToString() : QString("nullptr")));
       }
     }
     sources |= UpdateSelection(currentState);
@@ -404,7 +403,7 @@ SmartPointer<ShowInContext> WorkbenchSourceProvider::GetContext(const SmartPoint
 IWorkbenchWindow* WorkbenchSourceProvider::GetActiveWindow() const
 {
 //  IContextService* const contextService = workbench->GetService<IContextService>();
-//  if (contextService != NULL)
+//  if (contextService != nullptr)
 //  {
 //    const int shellType = contextService->GetShellType(qApp->activeWindow());
 //    if (shellType != IContextService::TYPE_DIALOG)
@@ -593,9 +592,9 @@ void WorkbenchSourceProvider::HandleShellEvent()
 //  }
 
   LogDebuggingInfo("\tWSP:lastActiveShell: " +
-                   (lastActiveShell ? lastActiveShell->GetControl()->objectName() : QString("NULL")));
+                   (!lastActiveShell.Expired() ? lastActiveShell.Lock()->GetControl()->objectName() : QString("nullptr")));
   LogDebuggingInfo("\tWSP:lastActiveWorkbenchWindowShell: " +
-                   (lastActiveWorkbenchWindowShell ? lastActiveWorkbenchWindowShell->GetControl()->objectName() : QString("NULL")));
+                   (!lastActiveWorkbenchWindowShell.Expired() ? lastActiveWorkbenchWindowShell.Lock()->GetControl()->objectName() : QString("nullptr")));
 
   const ISourceProvider::StateMapType currentState = GetCurrentState();
   const Shell::ConstPointer newActiveShell = currentState.value(ISources::ACTIVE_SHELL_NAME()).Cast<const Shell>();
@@ -632,8 +631,8 @@ void WorkbenchSourceProvider::HandleShellEvent()
   }
 
   // Figure out which variables have changed.
-  const bool shellChanged = newActiveShell != lastActiveShell;
-  const bool windowChanged = newActiveWorkbenchWindowShell != lastActiveWorkbenchWindowShell;
+  const bool shellChanged = newActiveShell != lastActiveShell.Lock();
+  const bool windowChanged = newActiveWorkbenchWindowShell != lastActiveWorkbenchWindowShell.Lock();
   const bool toolbarChanged = newToolbarVisibility != lastToolbarVisibility;
   const bool statusLineChanged = newStatusLineVis != lastStatusLineVisibility;
 
@@ -675,12 +674,12 @@ void WorkbenchSourceProvider::HandleShellEvent()
 
     if (DEBUG)
     {
-      LogDebuggingInfo("Active shell changed to " + (newActiveShell ? newActiveShell->ToString() : QString("NULL")));
-      LogDebuggingInfo("Active workbench window changed to " + (newActiveWorkbenchWindow ?  newActiveWorkbenchWindow->ToString() : QString("NULL")));
-      LogDebuggingInfo("Active workbench window shell changed to " + (newActiveWorkbenchWindowShell ? newActiveWorkbenchWindowShell->ToString() : QString("NULL")));
-      LogDebuggingInfo("Active workbench window coolbar visibility " + (newToolbarVisibility ? newToolbarVisibility->ToString() : QString("NULL")));
-      LogDebuggingInfo("Active workbench window perspective bar visibility " + (newPerspectiveBarVisibility ? newPerspectiveBarVisibility->ToString() : QString("NULL")));
-      LogDebuggingInfo("Active workbench window status line visibility " + (newStatusLineVis ? newStatusLineVis->ToString() : QString("NULL")));
+      LogDebuggingInfo("Active shell changed to " + (newActiveShell ? newActiveShell->ToString() : QString("nullptr")));
+      LogDebuggingInfo("Active workbench window changed to " + (newActiveWorkbenchWindow ?  newActiveWorkbenchWindow->ToString() : QString("nullptr")));
+      LogDebuggingInfo("Active workbench window shell changed to " + (newActiveWorkbenchWindowShell ? newActiveWorkbenchWindowShell->ToString() : QString("nullptr")));
+      LogDebuggingInfo("Active workbench window coolbar visibility " + (newToolbarVisibility ? newToolbarVisibility->ToString() : QString("nullptr")));
+      LogDebuggingInfo("Active workbench window perspective bar visibility " + (newPerspectiveBarVisibility ? newPerspectiveBarVisibility->ToString() : QString("nullptr")));
+      LogDebuggingInfo("Active workbench window status line visibility " + (newStatusLineVis ? newStatusLineVis->ToString() : QString("nullptr")));
     }
 
     FireSourceChanged(sourceFlags, sourceValuesByName);
@@ -690,7 +689,7 @@ void WorkbenchSourceProvider::HandleShellEvent()
   }
   else if (shellChanged)
   {
-    LogDebuggingInfo("Active shell changed to " + (newActiveShell ? newActiveShell->ToString() : QString("NULL")));
+    LogDebuggingInfo("Active shell changed to " + (newActiveShell ? newActiveShell->ToString() : QString("nullptr")));
     FireSourceChanged(ISources::ACTIVE_SHELL(), ISources::ACTIVE_SHELL_NAME(), newActiveShell);
   }
   else if (windowChanged)
@@ -730,11 +729,11 @@ void WorkbenchSourceProvider::HandleShellEvent()
 
     if (DEBUG)
     {
-      LogDebuggingInfo("Active workbench window changed to "  + (newActiveWorkbenchWindow ? newActiveWorkbenchWindow->ToString() : QString("NULL")));
-      LogDebuggingInfo("Active workbench window shell changed to " + (newActiveWorkbenchWindowShell ? newActiveWorkbenchWindowShell->ToString() : QString("NULL")));
-      LogDebuggingInfo("Active workbench window coolbar visibility " + (newToolbarVisibility ? newToolbarVisibility->ToString() : QString("NULL")));
-      LogDebuggingInfo("Active workbench window perspective bar visibility " + (newPerspectiveBarVisibility ? newPerspectiveBarVisibility->ToString() : QString("NULL")));
-      LogDebuggingInfo("Active workbench window status line visibility " + (newStatusLineVis ? newStatusLineVis->ToString() : QString("NULL")));
+      LogDebuggingInfo("Active workbench window changed to "  + (newActiveWorkbenchWindow ? newActiveWorkbenchWindow->ToString() : QString("nullptr")));
+      LogDebuggingInfo("Active workbench window shell changed to " + (newActiveWorkbenchWindowShell ? newActiveWorkbenchWindowShell->ToString() : QString("nullptr")));
+      LogDebuggingInfo("Active workbench window coolbar visibility " + (newToolbarVisibility ? newToolbarVisibility->ToString() : QString("nullptr")));
+      LogDebuggingInfo("Active workbench window perspective bar visibility " + (newPerspectiveBarVisibility ? newPerspectiveBarVisibility->ToString() : QString("nullptr")));
+      LogDebuggingInfo("Active workbench window status line visibility " + (newStatusLineVis ? newStatusLineVis->ToString() : QString("nullptr")));
     }
 
     FireSourceChanged(sourceFlags, sourceValuesByName);
@@ -748,8 +747,8 @@ void WorkbenchSourceProvider::HandleShellEvent()
   }
 
   // Update the member variables.
-  lastActiveShell = newActiveShell.GetPointer();
-  lastActiveWorkbenchWindowShell = newActiveWorkbenchWindowShell.GetPointer();
+  lastActiveShell = newActiveShell;
+  lastActiveWorkbenchWindowShell = newActiveWorkbenchWindowShell;
   lastActiveWorkbenchWindow = newActiveWorkbenchWindow;
   lastToolbarVisibility = newToolbarVisibility;
   lastStatusLineVisibility = newStatusLineVis;
@@ -765,12 +764,17 @@ void WorkbenchSourceProvider::CheckOtherSources(const SmartPointer<const Shell>&
 void WorkbenchSourceProvider::HandleInputChanged(const SmartPointer<IEditorPart>& editor)
 {
   IEditorInput::Pointer newInput = editor->GetEditorInput();
-  if (newInput != lastEditorInput)
+  IEditorInput::ConstPointer lastInput;
+  if (!lastEditorInput.Expired())
+  {
+    lastInput = lastEditorInput.Lock();
+  }
+  if (newInput != lastInput)
   {
     FireSourceChanged(ISources::ACTIVE_EDITOR(),
                       ISources::ACTIVE_EDITOR_INPUT_NAME(),
                       newInput.IsNull() ? IEvaluationContext::UNDEFINED_VARIABLE : Object::ConstPointer(newInput));
-    lastEditorInput = newInput.GetPointer();
+    lastEditorInput = newInput;
   }
 }
 
