@@ -1,25 +1,20 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
-#ifndef QMITKEDITORSPREFERENCEPAGE_H_
-#define QMITKEDITORSPREFERENCEPAGE_H_
+#ifndef QmitkEditorsPreferencePage_h
+#define QmitkEditorsPreferencePage_h
 
 #include "berryIQtPreferencePage.h"
-#include <berryIPreferences.h>
 
 class QWidget;
 
@@ -53,17 +48,17 @@ public:
   /**
   * @see berry::IPreferencePage::PerformOk()
   */
-  virtual bool PerformOk() override;
+  bool PerformOk() override;
 
   /**
   * @see berry::IPreferencePage::PerformCancel()
   */
-  virtual void PerformCancel() override;
+  void PerformCancel() override;
 
    /**
   * @see berry::IPreferencePage::Update()
   */
-  virtual void Update() override;
+  void Update() override;
 
 protected:
 
@@ -71,4 +66,4 @@ protected:
 
 };
 
-#endif /* QMITKEDITORSPREFERENCEPAGE_H_ */
+#endif
