@@ -1,25 +1,19 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-
-#ifndef QMITKGENERALPREFERENCEPAGE_H_
-#define QMITKGENERALPREFERENCEPAGE_H_
+#ifndef QmitkGeneralPreferencePage_h
+#define QmitkGeneralPreferencePage_h
 
 #include "berryIQtPreferencePage.h"
-#include <berryIPreferences.h>
 
 class QWidget;
 class QCheckBox;
@@ -31,9 +25,6 @@ class QmitkGeneralPreferencePage : public QObject, public berry::IQtPreferencePa
 
 public:
 
-  /**
-  * Default constructor
-  */
   QmitkGeneralPreferencePage();
 
   /**
@@ -54,22 +45,24 @@ public:
   /**
   * @see berry::IPreferencePage::PerformOk()
   */
-  virtual bool PerformOk() override;
+  bool PerformOk() override;
 
   /**
   * @see berry::IPreferencePage::PerformCancel()
   */
-  virtual void PerformCancel() override;
+  void PerformCancel() override;
 
    /**
   * @see berry::IPreferencePage::Update()
   */
-  virtual void Update() override;
+  void Update() override;
 
 protected:
 
     QWidget* m_MainControl;
 
+    QCheckBox* m_GlobalReinitOnNodeDelete;
+    QCheckBox* m_GlobalReinitOnNodeVisibilityChanged;
 };
 
-#endif /* QMITKGENERALPREFERENCEPAGE_H_ */
+#endif
