@@ -1,17 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) University College London (UCL).
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef CommandLineModulesViewControls_h
 #define CommandLineModulesViewControls_h
@@ -34,7 +31,7 @@ class CommandLineModulesViewControls : public QWidget, public Ui_CommandLineModu
 public:
 
   CommandLineModulesViewControls(QWidget *parent = nullptr);
-  virtual ~CommandLineModulesViewControls();
+  ~CommandLineModulesViewControls() override;
 
   void SetAdvancedWidgetsVisible(const bool& isVisible);
 
