@@ -1,17 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) University College London (UCL).
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "QmitkCmdLineModuleRunner.h"
 #include "ui_QmitkCmdLineModuleProgressWidget.h"
@@ -27,6 +24,7 @@ See LICENSE.txt or http://www.mitk.org for details.
 #include <QByteArray>
 #include <QApplication>
 #include <QRegExp>
+#include <QStyle>
 
 // CTK
 #include <ctkCmdLineModuleFuture.h>
@@ -48,12 +46,12 @@ See LICENSE.txt or http://www.mitk.org for details.
 //-----------------------------------------------------------------------------
 QmitkCmdLineModuleRunner::QmitkCmdLineModuleRunner(QWidget *parent)
   : QWidget(parent)
-, m_ModuleManager(NULL)
-, m_DataStorage(NULL)
+, m_ModuleManager(nullptr)
+, m_DataStorage(nullptr)
 , m_UI(new Ui::QmitkCmdLineModuleProgressWidget)
-, m_Layout(NULL)
-, m_ModuleFrontEnd(NULL)
-, m_FutureWatcher(NULL)
+, m_Layout(nullptr)
+, m_ModuleFrontEnd(nullptr)
+, m_FutureWatcher(nullptr)
 {
   m_UI->setupUi(this);
   m_UI->m_RemoveButton->setIcon(QApplication::style()->standardIcon(QStyle::SP_TitleBarCloseButton));
@@ -80,7 +78,7 @@ QmitkCmdLineModuleRunner::QmitkCmdLineModuleRunner(QWidget *parent)
 //-----------------------------------------------------------------------------
 QmitkCmdLineModuleRunner::~QmitkCmdLineModuleRunner()
 {
-  if (m_ModuleFrontEnd != NULL)
+  if (m_ModuleFrontEnd != nullptr)
   {
     delete m_ModuleFrontEnd;
   }
@@ -145,7 +143,7 @@ QString QmitkCmdLineModuleRunner::GetValidNodeName(const QString& nodeName) cons
   // This method is parsing a node name, and other bits of code add on a file extension .nii.
   // So, in the output string from this function, we should not allow period, so that
   // the second recommendation on this page:
-  // http://www.boost.org/doc/libs/1_43_0/libs/filesystem/doc/portability_guide.htm
+  // https://www.boost.org/doc/libs/1_43_0/libs/filesystem/doc/portability_guide.htm
   // is still true.
 
   QRegExp rx("[A-Z|a-z|0-9|-|_]{1,1}");
@@ -174,7 +172,7 @@ QString QmitkCmdLineModuleRunner::GetValidNodeName(const QString& nodeName) cons
 bool QmitkCmdLineModuleRunner::IsStarted() const
 {
   bool isStarted = false;
-  if (m_FutureWatcher != NULL && m_FutureWatcher->isStarted())
+  if (m_FutureWatcher != nullptr && m_FutureWatcher->isStarted())
   {
     isStarted = true;
   }
@@ -376,7 +374,7 @@ void QmitkCmdLineModuleRunner::ClearUpTemporaryFiles()
 
   foreach (QTemporaryFile* file, m_TemporaryFiles)
   {
-    assert(file != NULL);
+    assert(file != nullptr);
 
     fileName = file->fileName();
     message = QObject::tr("removing %1").arg(fileName);
@@ -538,12 +536,12 @@ void QmitkCmdLineModuleRunner::Run()
     if (node.IsNotNull())
     {
       mitk::Image* image = dynamic_cast<mitk::Image*>(node->GetData());
-      if (image != NULL)
+      if (image != nullptr)
       {
         QString errorMessage;
         QTemporaryFile* tempFile = this->SaveTemporaryImage(parameter, node.GetPointer(), errorMessage);
 
-        if(tempFile == NULL)
+        if(tempFile == nullptr)
         {
           QMessageBox::warning(this, "Saving temporary file failed", errorMessage);
           return;
@@ -566,7 +564,7 @@ void QmitkCmdLineModuleRunner::Run()
   message = "starting.";
   this->PublishMessage(message);
 
-  if (m_FutureWatcher == NULL)
+  if (m_FutureWatcher == nullptr)
   {
     m_FutureWatcher = new ctkCmdLineModuleFutureWatcher();
 
@@ -607,7 +605,7 @@ QTemporaryFile* QmitkCmdLineModuleRunner::SaveTemporaryImage(const ctkCmdLineMod
   QString intermediateError;
   QString intermediateErrors;
 
-  QTemporaryFile *returnedFile = NULL;
+  QTemporaryFile *returnedFile = nullptr;
   QString name = this->GetValidNodeName(QString::fromStdString(node->GetName()));
   QString fileNameTemplate = name + "_XXXXXX";
 
@@ -634,12 +632,13 @@ QTemporaryFile* QmitkCmdLineModuleRunner::SaveTemporaryImage(const ctkCmdLineMod
       if (tempFile->open())
       {
         tempFile->close();
-        if (mitk::IOUtil::SaveBaseData( image, tempFile->fileName().toStdString() ))
+        try
         {
+          mitk::IOUtil::Save( image, tempFile->fileName().toStdString() );
           returnedFile = tempFile;
           break;
         }
-        else
+        catch(const mitk::Exception &)
         {
           intermediateError = QObject::tr("Tried %1, failed to save image:\n%2\n").arg(extension).arg(tempFile->fileName());
         }
