@@ -1,29 +1,23 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
-#ifndef QMITKAPPINSTANCESPREFERENCEPAGE_H_
-#define QMITKAPPINSTANCESPREFERENCEPAGE_H_
+#ifndef QmitkAppInstancesPreferencePage_h
+#define QmitkAppInstancesPreferencePage_h
 
 #include <berryIQtPreferencePage.h>
-#include <berryIPreferences.h>
 
 #include <ui_QmitkAppInstancesPreferencePage.h>
 
-
 class QmitkAppInstancesPreferencePage : public QObject, public berry::IQtPreferencePage
 {
 
@@ -47,10 +41,7 @@ public:
 private:
 
   Ui::QmitkAppInstancesPreferencePage controls;
-
-  berry::IPreferences::Pointer prefs;
-
   QWidget* mainWidget;
 };
 
-#endif /* QMITKAPPINSTANCESPREFERENCEPAGE_H_ */
+#endif
