@@ -1,18 +1,17 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
+#ifndef QmitkExtWorkbenchWindowAdvisorHack_h
+#define QmitkExtWorkbenchWindowAdvisorHack_h
 
 #include <QObject>
 
@@ -53,7 +52,9 @@ class QmitkExtWorkbenchWindowAdvisorHack : public QObject
   public:
 
     QmitkExtWorkbenchWindowAdvisorHack();
-    ~QmitkExtWorkbenchWindowAdvisorHack();
+    ~QmitkExtWorkbenchWindowAdvisorHack() override;
 
     static QmitkExtWorkbenchWindowAdvisorHack* undohack;
 };
+
+#endif
