@@ -1,23 +1,18 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef QmitkExternalProgramsPreferencePage_h
 #define QmitkExternalProgramsPreferencePage_h
 
-#include <berryIPreferences.h>
 #include <berryIQtPreferencePage.h>
 #include <QProcess>
 #include <QScopedPointer>
@@ -34,7 +29,7 @@ class QmitkExternalProgramsPreferencePage : public QObject, public berry::IQtPre
 
 public:
   QmitkExternalProgramsPreferencePage();
-  ~QmitkExternalProgramsPreferencePage();
+  ~QmitkExternalProgramsPreferencePage() override;
 
   void CreateQtControl(QWidget* parent) override;
   QWidget* GetQtControl() const override;
@@ -44,22 +39,14 @@ public:
   void Update() override;
 
 private slots:
-  void OnFFmpegButtonClicked();
-  void OnFFmpegProcessError(QProcess::ProcessError error);
-  void OnFFmpegProcessFinished(int exitCode, QProcess::ExitStatus exitStatus);
-
   void OnGnuplotButtonClicked();
   void OnGnuplotProcessError(QProcess::ProcessError error);
   void OnGnuplotProcessFinished(int exitCode, QProcess::ExitStatus exitStatus);
 
 private:
-  berry::IPreferences::Pointer m_Preferences;
   QScopedPointer<Ui::QmitkExternalProgramsPreferencePage> m_Ui;
   QWidget* m_Control;
 
-  QProcess* m_FFmpegProcess;
-  QString m_FFmpegPath;
-
   QProcess* m_GnuplotProcess;
   QString m_GnuplotPath;
 };
