@@ -1,20 +1,17 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
+============================================================================*/
 
-===================================================================*/
-
-#ifndef _QMITKLABELGROUPWIDGET_H_INCLUDED
-#define _QMITKLABELGROUPWIDGET_H_INCLUDED
+#ifndef QmitkTubeGraphLabelGroupWidget_h
+#define QmitkTubeGraphLabelGroupWidget_h
 
 #include "mitkColorProperty.h"
 
@@ -28,7 +25,7 @@ class QmitkTubeGraphLabelGroupWidget : public QWidget
 
 public:
     QmitkTubeGraphLabelGroupWidget(QWidget *parent = nullptr, const char* name = nullptr);
-    virtual ~QmitkTubeGraphLabelGroupWidget();
+    ~QmitkTubeGraphLabelGroupWidget() override;
 
     void SetGroupName(QString name);
     QString GetGroupName();
