@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "QmitkXnatEditor.h"
 
@@ -38,7 +34,6 @@ See LICENSE.txt or http://www.mitk.org for details.
 // Blueberry
 #include <berryQModelIndexObject.h>
 #include <berryIWorkbenchPage.h>
-#include <berryPlatform.h>
 
 // Qt
 #include <QListView>
@@ -51,6 +46,9 @@ See LICENSE.txt or http://www.mitk.org for details.
 // MITK
 #include <mitkDataStorage.h>
 #include <QmitkIOUtil.h>
+#include <mitkCoreServices.h>
+#include <mitkIPreferencesService.h>
+#include <mitkIPreferences.h>
 
 // Poco
 #include <Poco/Zip/Decompress.h>
@@ -58,8 +56,8 @@ See LICENSE.txt or http://www.mitk.org for details.
 const QString QmitkXnatEditor::EDITOR_ID = "org.mitk.editors.xnat.browser";
 
 QmitkXnatEditor::QmitkXnatEditor() :
-m_DownloadPath(berry::Platform::GetPreferencesService()->
-GetSystemPreferences()->Node("/XnatConnection")->Get("Download Path", "")),
+m_DownloadPath(QString::fromStdString(mitk::CoreServices::GetPreferencesService()->
+GetSystemPreferences()->Node("/XnatConnection")->Get("Download Path", ""))),
 m_ListModel(new ctkXnatListModel()),
 m_Session(0),
 m_DataStorageServiceTracker(mitk::org_mitk_gui_qt_xnatinterface_Activator::GetContext()),
@@ -189,7 +187,7 @@ void QmitkXnatEditor::UpdateList()
   if (xoPtr.IsNull())
     return;
   ctkXnatObject* inputObject = xoPtr->GetXnatObject();
-  if (inputObject == NULL)
+  if (inputObject == nullptr)
     return;
 
   m_Controls.treeView->setModel(m_ListModel);
@@ -211,7 +209,7 @@ void QmitkXnatEditor::UpdateList()
     child->widget()->setVisible(false);
   }
 
-  ctkXnatObject* parent = NULL;
+  ctkXnatObject* parent = nullptr;
   for (int i = m_ParentCount * 2; i >= 0; i--)
   {
     if (i > 12)
@@ -224,7 +222,7 @@ void QmitkXnatEditor::UpdateList()
       m_Controls.breadcrumbHorizontalLayout->itemAt(i - 1)->widget()->setVisible(true);
       m_Controls.breadcrumbDescriptionLayout->itemAt(i - 1)->widget()->setVisible(true);
     }
-    if (parent == NULL)
+    if (parent == nullptr)
     {
       parent = inputObject;
     }
@@ -262,7 +260,7 @@ void QmitkXnatEditor::SelectionChanged(const berry::IWorkbenchPart::Pointer& sou
         ctkXnatObject* object = objectPointer->GetQModelIndex().data(Qt::UserRole).value<ctkXnatObject*>();
 
         // if a file is selected, don't change the input and list view
-        if (dynamic_cast<ctkXnatFile*>(object) == NULL)
+        if (dynamic_cast<ctkXnatFile*>(object) == nullptr)
         {
           QmitkXnatObjectEditorInput::Pointer oPtr(new QmitkXnatObjectEditorInput(object));
           berry::IEditorInput::Pointer editorInput(oPtr);
@@ -278,15 +276,15 @@ void QmitkXnatEditor::SelectionChanged(const berry::IWorkbenchPart::Pointer& sou
 
 void QmitkXnatEditor::DownloadResource()
 {
-  if (!m_Controls.treeView->selectionModel()->hasSelection())
+  if (!m_Controls.listView->selectionModel()->hasSelection())
     return;
 
-  const QModelIndex index = m_Controls.treeView->selectionModel()->currentIndex();
+  const QModelIndex index = m_Controls.listView->selectionModel()->currentIndex();
   QVariant variant = m_ListModel->data(index, Qt::UserRole);
   if (variant.isValid())
   {
     ctkXnatObject* resource = variant.value<ctkXnatObject*>();
-    if (dynamic_cast<ctkXnatFile*>(resource) == NULL)
+    if (dynamic_cast<ctkXnatFile*>(resource) == nullptr)
     {
       MITK_INFO << "Download started ...";
       MITK_INFO << "...";
@@ -312,10 +310,18 @@ void QmitkXnatEditor::DownloadResource()
   }
 }
 
+void QmitkXnatEditor::DownloadFile()
+{
+  if (!m_Controls.listView->selectionModel()->hasSelection())
+    return;
+  const QModelIndex index = m_Controls.listView->selectionModel()->currentIndex();
+  InternalFileDownload(index);
+}
+
 void QmitkXnatEditor::ToHigherLevel()
 {
   ctkXnatObject* parent = GetEditorInput().Cast<QmitkXnatObjectEditorInput>()->GetXnatObject()->parent();
-  if (parent == NULL)
+  if (parent == nullptr)
   {
     return;
   }
@@ -330,15 +336,15 @@ void QmitkXnatEditor::OnObjectActivated(const QModelIndex &index)
   if (!index.isValid()) return;
 
   ctkXnatObject* child = GetEditorInput().Cast<QmitkXnatObjectEditorInput>()->GetXnatObject()->children().at(index.row());
-  if (child != NULL)
+  if (child != nullptr)
   {
     ctkXnatFile* file = dynamic_cast<ctkXnatFile*>(child);
-    if (file != NULL)
+    if (file != nullptr)
     {
       // Download file and put into datamanager
       InternalFileDownload(index);
       mitk::IDataStorageService* dsService = m_DataStorageServiceTracker.getService();
-      if (dsService != NULL)
+      if (dsService != nullptr)
       {
         QString name = file->property("Name");
         QString filePath = m_DownloadPath + name;
@@ -389,7 +395,7 @@ void QmitkXnatEditor::InternalFileDownload(const QModelIndex& index)
   if (variant.isValid())
   {
     ctkXnatFile* file = dynamic_cast<ctkXnatFile*>(variant.value<ctkXnatObject*>());
-    if (file != NULL)
+    if (file != nullptr)
     {
       // Testing if the file exists
       QDir downDir(m_DownloadPath);
@@ -446,7 +452,7 @@ void QmitkXnatEditor::InternalFileDownload(const QModelIndex& index)
 int QmitkXnatEditor::ParentChecker(ctkXnatObject* child)
 {
   int sum;
-  if (child->parent() == NULL)
+  if (child->parent() == nullptr)
   {
     return 0;
   }
@@ -542,7 +548,7 @@ void QmitkXnatEditor::CleanListModel(ctkXnatSession* session)
 {
   if (session != 0)
   {
-    m_Controls.treeView->setModel(0);
+    m_Controls.listView->setModel(0);
     m_ListModel->setRootObject(0);
     m_Controls.treeView->reset();
   }
@@ -552,14 +558,14 @@ void QmitkXnatEditor::itemSelected(const QModelIndex &index)
 {
   ctkXnatObject* xnatObject = m_ListModel->data(index, Qt::UserRole).value<ctkXnatObject*>();
   bool downloadable = false;
-  downloadable |= dynamic_cast<ctkXnatFile*>(xnatObject) != NULL;
-  downloadable |= dynamic_cast<ctkXnatScan*>(xnatObject) != NULL;
-  downloadable |= dynamic_cast<ctkXnatScanFolder*>(xnatObject) != NULL;
-  downloadable |= dynamic_cast<ctkXnatAssessor*>(xnatObject) != NULL;
-  downloadable |= dynamic_cast<ctkXnatAssessorFolder*>(xnatObject) != NULL;
-  downloadable |= dynamic_cast<ctkXnatResource*>(xnatObject) != NULL;
-  downloadable |= dynamic_cast<ctkXnatReconstruction*>(xnatObject) != NULL;
-  downloadable |= dynamic_cast<ctkXnatReconstructionFolder*>(xnatObject) != NULL;
+  downloadable |= dynamic_cast<ctkXnatFile*>(xnatObject) != nullptr;
+  downloadable |= dynamic_cast<ctkXnatScan*>(xnatObject) != nullptr;
+  downloadable |= dynamic_cast<ctkXnatScanFolder*>(xnatObject) != nullptr;
+  downloadable |= dynamic_cast<ctkXnatAssessor*>(xnatObject) != nullptr;
+  downloadable |= dynamic_cast<ctkXnatAssessorFolder*>(xnatObject) != nullptr;
+  downloadable |= dynamic_cast<ctkXnatResource*>(xnatObject) != nullptr;
+  downloadable |= dynamic_cast<ctkXnatReconstruction*>(xnatObject) != nullptr;
+  downloadable |= dynamic_cast<ctkXnatReconstructionFolder*>(xnatObject) != nullptr;
   m_Controls.buttonDownload->setEnabled(downloadable);
   m_Controls.labelDownload->setVisible(!downloadable);
 }
