@@ -1,22 +1,18 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
-#ifndef MITKPLANARFIGUREACTIVATOR_H_
-#define MITKPLANARFIGUREACTIVATOR_H_
+#ifndef mitkPlanarFigureActivator_h
+#define mitkPlanarFigureActivator_h
 
 #include <ctkPluginActivator.h>
 
@@ -36,9 +32,7 @@ class PlanarFigureActivator :
 {
 
   Q_OBJECT
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
   Q_PLUGIN_METADATA(IID "org_mitk_planarfigure")
-#endif
   Q_INTERFACES(ctkPluginActivator)
 
 public:
@@ -52,4 +46,4 @@ public:
 };
 
 }
-#endif /* MITKPLANARFIGUREACTIVATOR_H_  */
+#endif
